/****************************************************************************
** Meta object code from reading C++ file 'dblockdevice.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../udisks2-qt6/dblockdevice.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'dblockdevice.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN12DBlockDeviceE_t {};
} // unnamed namespace

template <> constexpr inline auto DBlockDevice::qt_create_metaobjectdata<qt_meta_tag_ZN12DBlockDeviceE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "DBlockDevice",
        "hasFileSystemChanged",
        "",
        "hasFileSystem",
        "hasPartitionChanged",
        "hasPartition",
        "isEncryptedChanged",
        "isEncrypted",
        "configurationChanged",
        "QList<std::pair<QString,QVariantMap>>",
        "configuration",
        "cryptoBackingDeviceChanged",
        "cryptoBackingDevice",
        "hintAutoChanged",
        "hintAuto",
        "hintIconNameChanged",
        "hintIconName",
        "hintIgnoreChanged",
        "hintIgnore",
        "hintNameChanged",
        "hintName",
        "hintPartitionableChanged",
        "hintPartitionable",
        "hintSymbolicIconNameChanged",
        "hintSymbolicIconName",
        "idLabelChanged",
        "idLabel",
        "idTypeChanged",
        "idType",
        "fsTypeChanged",
        "idUUIDChanged",
        "idUUID",
        "idUsageChanged",
        "idUsage",
        "idVersionChanged",
        "idVersion",
        "mDRaidChanged",
        "mDRaid",
        "mDRaidMemberChanged",
        "mDRaidMember",
        "preferredDeviceChanged",
        "preferredDevice",
        "readOnlyChanged",
        "readOnly",
        "sizeChanged",
        "size",
        "symlinksChanged",
        "QByteArrayList",
        "symlinks",
        "userspaceMountOptionsChanged",
        "userspaceMountOptions",
        "ptTypeChanged",
        "mountPointsChanged",
        "mountPoints",
        "childConfigurationChanged",
        "childConfiguration",
        "cleartextDeviceChanged",
        "cleartextDevice",
        "setWatchChanges",
        "watchChanges",
        "addConfigurationItem",
        "std::pair<QString,QVariantMap>",
        "item",
        "QVariantMap",
        "options",
        "format",
        "type",
        "FSType",
        "getSecretConfiguration",
        "openDevice",
        "QDBusUnixFileDescriptor",
        "mode",
        "openForBackup",
        "openForBenchmark",
        "openForRestore",
        "removeConfigurationItem",
        "rescan",
        "updateConfigurationItem",
        "old_item",
        "new_item",
        "mount",
        "unmount",
        "canSetLabel",
        "setLabel",
        "label",
        "changePassphrase",
        "passphrase",
        "new_passphrase",
        "lock",
        "unlock",
        "onInterfacesAdded",
        "QDBusObjectPath",
        "object_path",
        "QMap<QString,QVariantMap>",
        "interfaces_and_properties",
        "onInterfacesRemoved",
        "interfaces",
        "onPropertiesChanged",
        "interface",
        "changed_properties",
        "path",
        "isLoopDevice",
        "device",
        "deviceNumber",
        "drive",
        "hintSystem",
        "id",
        "fsType",
        "ptType",
        "PTType",
        "InvalidPT",
        "MBR",
        "GPT",
        "UnknowPT",
        "InvalidFS",
        "UnknowFS",
        "ext2",
        "ext3",
        "ext4",
        "fat12",
        "fat16",
        "fat32",
        "btrfs",
        "f2fs",
        "hfs_plus",
        "minix",
        "nilfs2",
        "ntfs",
        "reiser4",
        "vfat",
        "iso9660",
        "jfs",
        "xfs",
        "swap",
        "LVM2_member",
        "crypto_LUKS"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'hasFileSystemChanged'
        QtMocHelpers::SignalData<void(bool)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 3 },
        }}),
        // Signal 'hasPartitionChanged'
        QtMocHelpers::SignalData<void(bool)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 5 },
        }}),
        // Signal 'isEncryptedChanged'
        QtMocHelpers::SignalData<void(bool)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 7 },
        }}),
        // Signal 'configurationChanged'
        QtMocHelpers::SignalData<void(QList<QPair<QString,QVariantMap>>)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 9, 10 },
        }}),
        // Signal 'cryptoBackingDeviceChanged'
        QtMocHelpers::SignalData<void(QString)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 12 },
        }}),
        // Signal 'hintAutoChanged'
        QtMocHelpers::SignalData<void(bool)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 14 },
        }}),
        // Signal 'hintIconNameChanged'
        QtMocHelpers::SignalData<void(QString)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 16 },
        }}),
        // Signal 'hintIgnoreChanged'
        QtMocHelpers::SignalData<void(bool)>(17, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 18 },
        }}),
        // Signal 'hintNameChanged'
        QtMocHelpers::SignalData<void(QString)>(19, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 20 },
        }}),
        // Signal 'hintPartitionableChanged'
        QtMocHelpers::SignalData<void(bool)>(21, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 22 },
        }}),
        // Signal 'hintSymbolicIconNameChanged'
        QtMocHelpers::SignalData<void(QString)>(23, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 24 },
        }}),
        // Signal 'idLabelChanged'
        QtMocHelpers::SignalData<void(QString)>(25, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 26 },
        }}),
        // Signal 'idTypeChanged'
        QtMocHelpers::SignalData<void(QString)>(27, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 28 },
        }}),
        // Signal 'fsTypeChanged'
        QtMocHelpers::SignalData<void()>(29, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'idUUIDChanged'
        QtMocHelpers::SignalData<void(QString)>(30, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 31 },
        }}),
        // Signal 'idUsageChanged'
        QtMocHelpers::SignalData<void(QString)>(32, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 33 },
        }}),
        // Signal 'idVersionChanged'
        QtMocHelpers::SignalData<void(QString)>(34, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 35 },
        }}),
        // Signal 'mDRaidChanged'
        QtMocHelpers::SignalData<void(QString)>(36, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 37 },
        }}),
        // Signal 'mDRaidMemberChanged'
        QtMocHelpers::SignalData<void(QString)>(38, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 39 },
        }}),
        // Signal 'preferredDeviceChanged'
        QtMocHelpers::SignalData<void(QByteArray)>(40, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QByteArray, 41 },
        }}),
        // Signal 'readOnlyChanged'
        QtMocHelpers::SignalData<void(bool)>(42, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 43 },
        }}),
        // Signal 'sizeChanged'
        QtMocHelpers::SignalData<void(qulonglong)>(44, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::ULongLong, 45 },
        }}),
        // Signal 'symlinksChanged'
        QtMocHelpers::SignalData<void(QByteArrayList)>(46, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 47, 48 },
        }}),
        // Signal 'userspaceMountOptionsChanged'
        QtMocHelpers::SignalData<void(QStringList)>(49, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QStringList, 50 },
        }}),
        // Signal 'ptTypeChanged'
        QtMocHelpers::SignalData<void()>(51, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'mountPointsChanged'
        QtMocHelpers::SignalData<void(const QByteArrayList &)>(52, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 47, 53 },
        }}),
        // Signal 'childConfigurationChanged'
        QtMocHelpers::SignalData<void(QList<QPair<QString,QVariantMap>>)>(54, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 9, 55 },
        }}),
        // Signal 'cleartextDeviceChanged'
        QtMocHelpers::SignalData<void(const QString &)>(56, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 57 },
        }}),
        // Slot 'setWatchChanges'
        QtMocHelpers::SlotData<void(bool)>(58, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 59 },
        }}),
        // Slot 'addConfigurationItem'
        QtMocHelpers::SlotData<void(const QPair<QString,QVariantMap> &, const QVariantMap &)>(60, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 61, 62 }, { 0x80000000 | 63, 64 },
        }}),
        // Slot 'format'
        QtMocHelpers::SlotData<void(const QString &, const QVariantMap &)>(65, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 66 }, { 0x80000000 | 63, 64 },
        }}),
        // Slot 'format'
        QtMocHelpers::SlotData<void(const FSType &, const QVariantMap &)>(65, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 67, 66 }, { 0x80000000 | 63, 64 },
        }}),
        // Slot 'getSecretConfiguration'
        QtMocHelpers::SlotData<QList<QPair<QString,QVariantMap>>(const QVariantMap &)>(68, 2, QMC::AccessPublic, 0x80000000 | 9, {{
            { 0x80000000 | 63, 64 },
        }}),
        // Slot 'openDevice'
        QtMocHelpers::SlotData<QDBusUnixFileDescriptor(const QString &, const QVariantMap &)>(69, 2, QMC::AccessPublic, 0x80000000 | 70, {{
            { QMetaType::QString, 71 }, { 0x80000000 | 63, 64 },
        }}),
        // Slot 'openForBackup'
        QtMocHelpers::SlotData<QDBusUnixFileDescriptor(const QVariantMap &)>(72, 2, QMC::AccessPublic, 0x80000000 | 70, {{
            { 0x80000000 | 63, 64 },
        }}),
        // Slot 'openForBenchmark'
        QtMocHelpers::SlotData<QDBusUnixFileDescriptor(const QVariantMap &)>(73, 2, QMC::AccessPublic, 0x80000000 | 70, {{
            { 0x80000000 | 63, 64 },
        }}),
        // Slot 'openForRestore'
        QtMocHelpers::SlotData<QDBusUnixFileDescriptor(const QVariantMap &)>(74, 2, QMC::AccessPublic, 0x80000000 | 70, {{
            { 0x80000000 | 63, 64 },
        }}),
        // Slot 'removeConfigurationItem'
        QtMocHelpers::SlotData<void(const QPair<QString,QVariantMap> &, const QVariantMap &)>(75, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 61, 62 }, { 0x80000000 | 63, 64 },
        }}),
        // Slot 'rescan'
        QtMocHelpers::SlotData<void(const QVariantMap &)>(76, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 63, 64 },
        }}),
        // Slot 'updateConfigurationItem'
        QtMocHelpers::SlotData<void(const QPair<QString,QVariantMap> &, const QPair<QString,QVariantMap> &, const QVariantMap &)>(77, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 61, 78 }, { 0x80000000 | 61, 79 }, { 0x80000000 | 63, 64 },
        }}),
        // Slot 'mount'
        QtMocHelpers::SlotData<QString(const QVariantMap &)>(80, 2, QMC::AccessPublic, QMetaType::QString, {{
            { 0x80000000 | 63, 64 },
        }}),
        // Slot 'unmount'
        QtMocHelpers::SlotData<void(const QVariantMap &)>(81, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 63, 64 },
        }}),
        // Slot 'canSetLabel'
        QtMocHelpers::SlotData<bool() const>(82, 2, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'setLabel'
        QtMocHelpers::SlotData<void(const QString &, const QVariantMap &)>(83, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 84 }, { 0x80000000 | 63, 64 },
        }}),
        // Slot 'changePassphrase'
        QtMocHelpers::SlotData<void(const QString &, const QString &, const QVariantMap &)>(85, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 86 }, { QMetaType::QString, 87 }, { 0x80000000 | 63, 64 },
        }}),
        // Slot 'lock'
        QtMocHelpers::SlotData<void(const QVariantMap &)>(88, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 63, 64 },
        }}),
        // Slot 'unlock'
        QtMocHelpers::SlotData<QString(const QString &, const QVariantMap &)>(89, 2, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::QString, 86 }, { 0x80000000 | 63, 64 },
        }}),
        // Slot 'cleartextDevice'
        QtMocHelpers::SlotData<QString()>(57, 2, QMC::AccessPublic, QMetaType::QString),
        // Slot 'onInterfacesAdded'
        QtMocHelpers::SlotData<void(const QDBusObjectPath &, const QMap<QString,QVariantMap> &)>(90, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 91, 92 }, { 0x80000000 | 93, 94 },
        }}),
        // Slot 'onInterfacesRemoved'
        QtMocHelpers::SlotData<void(const QDBusObjectPath &, const QStringList &)>(95, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 91, 92 }, { QMetaType::QStringList, 96 },
        }}),
        // Slot 'onPropertiesChanged'
        QtMocHelpers::SlotData<void(const QString &, const QVariantMap &)>(97, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 98 }, { 0x80000000 | 63, 99 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'path'
        QtMocHelpers::PropertyData<QString>(100, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant | QMC::Final),
        // property 'watchChanges'
        QtMocHelpers::PropertyData<bool>(59, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'hasFileSystem'
        QtMocHelpers::PropertyData<bool>(3, QMetaType::Bool, QMC::DefaultPropertyFlags, 0),
        // property 'hasPartition'
        QtMocHelpers::PropertyData<bool>(5, QMetaType::Bool, QMC::DefaultPropertyFlags, 1),
        // property 'isEncrypted'
        QtMocHelpers::PropertyData<bool>(7, QMetaType::Bool, QMC::DefaultPropertyFlags, 2),
        // property 'isLoopDevice'
        QtMocHelpers::PropertyData<bool>(101, QMetaType::Bool, QMC::DefaultPropertyFlags),
        // property 'configuration'
        QtMocHelpers::PropertyData<QList<std::pair<QString,QVariantMap>>>(10, 0x80000000 | 9, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 3),
        // property 'cryptoBackingDevice'
        QtMocHelpers::PropertyData<QString>(12, QMetaType::QString, QMC::DefaultPropertyFlags, 4),
        // property 'device'
        QtMocHelpers::PropertyData<QByteArray>(102, QMetaType::QByteArray, QMC::DefaultPropertyFlags),
        // property 'deviceNumber'
        QtMocHelpers::PropertyData<qulonglong>(103, QMetaType::ULongLong, QMC::DefaultPropertyFlags),
        // property 'drive'
        QtMocHelpers::PropertyData<QString>(104, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'hintAuto'
        QtMocHelpers::PropertyData<bool>(14, QMetaType::Bool, QMC::DefaultPropertyFlags, 5),
        // property 'hintIconName'
        QtMocHelpers::PropertyData<QString>(16, QMetaType::QString, QMC::DefaultPropertyFlags, 6),
        // property 'hintIgnore'
        QtMocHelpers::PropertyData<bool>(18, QMetaType::Bool, QMC::DefaultPropertyFlags, 7),
        // property 'hintName'
        QtMocHelpers::PropertyData<QString>(20, QMetaType::QString, QMC::DefaultPropertyFlags, 8),
        // property 'hintPartitionable'
        QtMocHelpers::PropertyData<bool>(22, QMetaType::Bool, QMC::DefaultPropertyFlags, 9),
        // property 'hintSymbolicIconName'
        QtMocHelpers::PropertyData<QString>(24, QMetaType::QString, QMC::DefaultPropertyFlags, 10),
        // property 'hintSystem'
        QtMocHelpers::PropertyData<bool>(105, QMetaType::Bool, QMC::DefaultPropertyFlags),
        // property 'id'
        QtMocHelpers::PropertyData<QString>(106, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'idLabel'
        QtMocHelpers::PropertyData<QString>(26, QMetaType::QString, QMC::DefaultPropertyFlags, 11),
        // property 'idType'
        QtMocHelpers::PropertyData<QString>(28, QMetaType::QString, QMC::DefaultPropertyFlags, 12),
        // property 'fsType'
        QtMocHelpers::PropertyData<enum FSType>(107, 0x80000000 | 67, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 13),
        // property 'idUUID'
        QtMocHelpers::PropertyData<QString>(31, QMetaType::QString, QMC::DefaultPropertyFlags, 14),
        // property 'idUsage'
        QtMocHelpers::PropertyData<QString>(33, QMetaType::QString, QMC::DefaultPropertyFlags, 15),
        // property 'idVersion'
        QtMocHelpers::PropertyData<QString>(35, QMetaType::QString, QMC::DefaultPropertyFlags, 16),
        // property 'mDRaid'
        QtMocHelpers::PropertyData<QString>(37, QMetaType::QString, QMC::DefaultPropertyFlags, 17),
        // property 'mDRaidMember'
        QtMocHelpers::PropertyData<QString>(39, QMetaType::QString, QMC::DefaultPropertyFlags, 18),
        // property 'preferredDevice'
        QtMocHelpers::PropertyData<QByteArray>(41, QMetaType::QByteArray, QMC::DefaultPropertyFlags, 19),
        // property 'readOnly'
        QtMocHelpers::PropertyData<bool>(43, QMetaType::Bool, QMC::DefaultPropertyFlags, 20),
        // property 'size'
        QtMocHelpers::PropertyData<qulonglong>(45, QMetaType::ULongLong, QMC::DefaultPropertyFlags, 21),
        // property 'symlinks'
        QtMocHelpers::PropertyData<QByteArrayList>(48, 0x80000000 | 47, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 22),
        // property 'userspaceMountOptions'
        QtMocHelpers::PropertyData<QStringList>(50, QMetaType::QStringList, QMC::DefaultPropertyFlags, 23),
        // property 'mountPoints'
        QtMocHelpers::PropertyData<QByteArrayList>(53, 0x80000000 | 47, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 25),
        // property 'ptType'
        QtMocHelpers::PropertyData<enum PTType>(108, 0x80000000 | 109, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 24),
        // property 'childConfiguration'
        QtMocHelpers::PropertyData<QList<std::pair<QString,QVariantMap>>>(55, 0x80000000 | 9, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 26),
        // property 'cleartextDevice'
        QtMocHelpers::PropertyData<QString>(57, QMetaType::QString, QMC::DefaultPropertyFlags, 27),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'PTType'
        QtMocHelpers::EnumData<enum PTType>(109, 109, QMC::EnumFlags{}).add({
            {  110, PTType::InvalidPT },
            {  111, PTType::MBR },
            {  112, PTType::GPT },
            {  113, PTType::UnknowPT },
        }),
        // enum 'FSType'
        QtMocHelpers::EnumData<enum FSType>(67, 67, QMC::EnumFlags{}).add({
            {  114, FSType::InvalidFS },
            {  115, FSType::UnknowFS },
            {  116, FSType::ext2 },
            {  117, FSType::ext3 },
            {  118, FSType::ext4 },
            {  119, FSType::fat12 },
            {  120, FSType::fat16 },
            {  121, FSType::fat32 },
            {  122, FSType::btrfs },
            {  123, FSType::f2fs },
            {  124, FSType::hfs_plus },
            {  125, FSType::minix },
            {  126, FSType::nilfs2 },
            {  127, FSType::ntfs },
            {  128, FSType::reiser4 },
            {  129, FSType::vfat },
            {  130, FSType::iso9660 },
            {  131, FSType::jfs },
            {  132, FSType::xfs },
            {  133, FSType::swap },
            {  134, FSType::LVM2_member },
            {  135, FSType::crypto_LUKS },
        }),
    };
    return QtMocHelpers::metaObjectData<DBlockDevice, qt_meta_tag_ZN12DBlockDeviceE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject DBlockDevice::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12DBlockDeviceE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12DBlockDeviceE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN12DBlockDeviceE_t>.metaTypes,
    nullptr
} };

void DBlockDevice::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<DBlockDevice *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->hasFileSystemChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 1: _t->hasPartitionChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 2: _t->isEncryptedChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 3: _t->configurationChanged((*reinterpret_cast<std::add_pointer_t<QList<std::pair<QString,QVariantMap>>>>(_a[1]))); break;
        case 4: _t->cryptoBackingDeviceChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 5: _t->hintAutoChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 6: _t->hintIconNameChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 7: _t->hintIgnoreChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 8: _t->hintNameChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 9: _t->hintPartitionableChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 10: _t->hintSymbolicIconNameChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 11: _t->idLabelChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 12: _t->idTypeChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 13: _t->fsTypeChanged(); break;
        case 14: _t->idUUIDChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 15: _t->idUsageChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 16: _t->idVersionChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 17: _t->mDRaidChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 18: _t->mDRaidMemberChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 19: _t->preferredDeviceChanged((*reinterpret_cast<std::add_pointer_t<QByteArray>>(_a[1]))); break;
        case 20: _t->readOnlyChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 21: _t->sizeChanged((*reinterpret_cast<std::add_pointer_t<qulonglong>>(_a[1]))); break;
        case 22: _t->symlinksChanged((*reinterpret_cast<std::add_pointer_t<QByteArrayList>>(_a[1]))); break;
        case 23: _t->userspaceMountOptionsChanged((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1]))); break;
        case 24: _t->ptTypeChanged(); break;
        case 25: _t->mountPointsChanged((*reinterpret_cast<std::add_pointer_t<QByteArrayList>>(_a[1]))); break;
        case 26: _t->childConfigurationChanged((*reinterpret_cast<std::add_pointer_t<QList<std::pair<QString,QVariantMap>>>>(_a[1]))); break;
        case 27: _t->cleartextDeviceChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 28: _t->setWatchChanges((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 29: _t->addConfigurationItem((*reinterpret_cast<std::add_pointer_t<std::pair<QString,QVariantMap>>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[2]))); break;
        case 30: _t->format((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[2]))); break;
        case 31: _t->format((*reinterpret_cast<std::add_pointer_t<enum FSType>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[2]))); break;
        case 32: { QList<std::pair<QString,QVariantMap>> _r = _t->getSecretConfiguration((*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QList<std::pair<QString,QVariantMap>>*>(_a[0]) = std::move(_r); }  break;
        case 33: { QDBusUnixFileDescriptor _r = _t->openDevice((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QDBusUnixFileDescriptor*>(_a[0]) = std::move(_r); }  break;
        case 34: { QDBusUnixFileDescriptor _r = _t->openForBackup((*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusUnixFileDescriptor*>(_a[0]) = std::move(_r); }  break;
        case 35: { QDBusUnixFileDescriptor _r = _t->openForBenchmark((*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusUnixFileDescriptor*>(_a[0]) = std::move(_r); }  break;
        case 36: { QDBusUnixFileDescriptor _r = _t->openForRestore((*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusUnixFileDescriptor*>(_a[0]) = std::move(_r); }  break;
        case 37: _t->removeConfigurationItem((*reinterpret_cast<std::add_pointer_t<std::pair<QString,QVariantMap>>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[2]))); break;
        case 38: _t->rescan((*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[1]))); break;
        case 39: _t->updateConfigurationItem((*reinterpret_cast<std::add_pointer_t<std::pair<QString,QVariantMap>>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<std::pair<QString,QVariantMap>>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[3]))); break;
        case 40: { QString _r = _t->mount((*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 41: _t->unmount((*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[1]))); break;
        case 42: { bool _r = _t->canSetLabel();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 43: _t->setLabel((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[2]))); break;
        case 44: _t->changePassphrase((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[3]))); break;
        case 45: _t->lock((*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[1]))); break;
        case 46: { QString _r = _t->unlock((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 47: { QString _r = _t->cleartextDevice();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 48: _t->onInterfacesAdded((*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QMap<QString,QVariantMap>>>(_a[2]))); break;
        case 49: _t->onInterfacesRemoved((*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[2]))); break;
        case 50: _t->onPropertiesChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[2]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (DBlockDevice::*)(bool )>(_a, &DBlockDevice::hasFileSystemChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (DBlockDevice::*)(bool )>(_a, &DBlockDevice::hasPartitionChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (DBlockDevice::*)(bool )>(_a, &DBlockDevice::isEncryptedChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (DBlockDevice::*)(QList<QPair<QString,QVariantMap>> )>(_a, &DBlockDevice::configurationChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (DBlockDevice::*)(QString )>(_a, &DBlockDevice::cryptoBackingDeviceChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (DBlockDevice::*)(bool )>(_a, &DBlockDevice::hintAutoChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (DBlockDevice::*)(QString )>(_a, &DBlockDevice::hintIconNameChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (DBlockDevice::*)(bool )>(_a, &DBlockDevice::hintIgnoreChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (DBlockDevice::*)(QString )>(_a, &DBlockDevice::hintNameChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (DBlockDevice::*)(bool )>(_a, &DBlockDevice::hintPartitionableChanged, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (DBlockDevice::*)(QString )>(_a, &DBlockDevice::hintSymbolicIconNameChanged, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (DBlockDevice::*)(QString )>(_a, &DBlockDevice::idLabelChanged, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (DBlockDevice::*)(QString )>(_a, &DBlockDevice::idTypeChanged, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (DBlockDevice::*)()>(_a, &DBlockDevice::fsTypeChanged, 13))
            return;
        if (QtMocHelpers::indexOfMethod<void (DBlockDevice::*)(QString )>(_a, &DBlockDevice::idUUIDChanged, 14))
            return;
        if (QtMocHelpers::indexOfMethod<void (DBlockDevice::*)(QString )>(_a, &DBlockDevice::idUsageChanged, 15))
            return;
        if (QtMocHelpers::indexOfMethod<void (DBlockDevice::*)(QString )>(_a, &DBlockDevice::idVersionChanged, 16))
            return;
        if (QtMocHelpers::indexOfMethod<void (DBlockDevice::*)(QString )>(_a, &DBlockDevice::mDRaidChanged, 17))
            return;
        if (QtMocHelpers::indexOfMethod<void (DBlockDevice::*)(QString )>(_a, &DBlockDevice::mDRaidMemberChanged, 18))
            return;
        if (QtMocHelpers::indexOfMethod<void (DBlockDevice::*)(QByteArray )>(_a, &DBlockDevice::preferredDeviceChanged, 19))
            return;
        if (QtMocHelpers::indexOfMethod<void (DBlockDevice::*)(bool )>(_a, &DBlockDevice::readOnlyChanged, 20))
            return;
        if (QtMocHelpers::indexOfMethod<void (DBlockDevice::*)(qulonglong )>(_a, &DBlockDevice::sizeChanged, 21))
            return;
        if (QtMocHelpers::indexOfMethod<void (DBlockDevice::*)(QByteArrayList )>(_a, &DBlockDevice::symlinksChanged, 22))
            return;
        if (QtMocHelpers::indexOfMethod<void (DBlockDevice::*)(QStringList )>(_a, &DBlockDevice::userspaceMountOptionsChanged, 23))
            return;
        if (QtMocHelpers::indexOfMethod<void (DBlockDevice::*)()>(_a, &DBlockDevice::ptTypeChanged, 24))
            return;
        if (QtMocHelpers::indexOfMethod<void (DBlockDevice::*)(const QByteArrayList & )>(_a, &DBlockDevice::mountPointsChanged, 25))
            return;
        if (QtMocHelpers::indexOfMethod<void (DBlockDevice::*)(QList<QPair<QString,QVariantMap>> )>(_a, &DBlockDevice::childConfigurationChanged, 26))
            return;
        if (QtMocHelpers::indexOfMethod<void (DBlockDevice::*)(const QString & )>(_a, &DBlockDevice::cleartextDeviceChanged, 27))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->path(); break;
        case 1: *reinterpret_cast<bool*>(_v) = _t->watchChanges(); break;
        case 2: *reinterpret_cast<bool*>(_v) = _t->hasFileSystem(); break;
        case 3: *reinterpret_cast<bool*>(_v) = _t->hasPartition(); break;
        case 4: *reinterpret_cast<bool*>(_v) = _t->isEncrypted(); break;
        case 5: *reinterpret_cast<bool*>(_v) = _t->isLoopDevice(); break;
        case 6: *reinterpret_cast<QList<std::pair<QString,QVariantMap>>*>(_v) = _t->configuration(); break;
        case 7: *reinterpret_cast<QString*>(_v) = _t->cryptoBackingDevice(); break;
        case 8: *reinterpret_cast<QByteArray*>(_v) = _t->device(); break;
        case 9: *reinterpret_cast<qulonglong*>(_v) = _t->deviceNumber(); break;
        case 10: *reinterpret_cast<QString*>(_v) = _t->drive(); break;
        case 11: *reinterpret_cast<bool*>(_v) = _t->hintAuto(); break;
        case 12: *reinterpret_cast<QString*>(_v) = _t->hintIconName(); break;
        case 13: *reinterpret_cast<bool*>(_v) = _t->hintIgnore(); break;
        case 14: *reinterpret_cast<QString*>(_v) = _t->hintName(); break;
        case 15: *reinterpret_cast<bool*>(_v) = _t->hintPartitionable(); break;
        case 16: *reinterpret_cast<QString*>(_v) = _t->hintSymbolicIconName(); break;
        case 17: *reinterpret_cast<bool*>(_v) = _t->hintSystem(); break;
        case 18: *reinterpret_cast<QString*>(_v) = _t->id(); break;
        case 19: *reinterpret_cast<QString*>(_v) = _t->idLabel(); break;
        case 20: *reinterpret_cast<QString*>(_v) = _t->idType(); break;
        case 21: *reinterpret_cast<enum FSType*>(_v) = _t->fsType(); break;
        case 22: *reinterpret_cast<QString*>(_v) = _t->idUUID(); break;
        case 23: *reinterpret_cast<QString*>(_v) = _t->idUsage(); break;
        case 24: *reinterpret_cast<QString*>(_v) = _t->idVersion(); break;
        case 25: *reinterpret_cast<QString*>(_v) = _t->mDRaid(); break;
        case 26: *reinterpret_cast<QString*>(_v) = _t->mDRaidMember(); break;
        case 27: *reinterpret_cast<QByteArray*>(_v) = _t->preferredDevice(); break;
        case 28: *reinterpret_cast<bool*>(_v) = _t->readOnly(); break;
        case 29: *reinterpret_cast<qulonglong*>(_v) = _t->size(); break;
        case 30: *reinterpret_cast<QByteArrayList*>(_v) = _t->symlinks(); break;
        case 31: *reinterpret_cast<QStringList*>(_v) = _t->userspaceMountOptions(); break;
        case 32: *reinterpret_cast<QByteArrayList*>(_v) = _t->mountPoints(); break;
        case 33: *reinterpret_cast<enum PTType*>(_v) = _t->ptType(); break;
        case 34: *reinterpret_cast<QList<std::pair<QString,QVariantMap>>*>(_v) = _t->childConfiguration(); break;
        case 35: *reinterpret_cast<QString*>(_v) = _t->cleartextDevice(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 1: _t->setWatchChanges(*reinterpret_cast<bool*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *DBlockDevice::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *DBlockDevice::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12DBlockDeviceE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int DBlockDevice::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 51)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 51;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 51)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 51;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 36;
    }
    return _id;
}

// SIGNAL 0
void DBlockDevice::hasFileSystemChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void DBlockDevice::hasPartitionChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void DBlockDevice::isEncryptedChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void DBlockDevice::configurationChanged(QList<QPair<QString,QVariantMap>> _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void DBlockDevice::cryptoBackingDeviceChanged(QString _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void DBlockDevice::hintAutoChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void DBlockDevice::hintIconNameChanged(QString _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void DBlockDevice::hintIgnoreChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1);
}

// SIGNAL 8
void DBlockDevice::hintNameChanged(QString _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 8, nullptr, _t1);
}

// SIGNAL 9
void DBlockDevice::hintPartitionableChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 9, nullptr, _t1);
}

// SIGNAL 10
void DBlockDevice::hintSymbolicIconNameChanged(QString _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 10, nullptr, _t1);
}

// SIGNAL 11
void DBlockDevice::idLabelChanged(QString _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 11, nullptr, _t1);
}

// SIGNAL 12
void DBlockDevice::idTypeChanged(QString _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 12, nullptr, _t1);
}

// SIGNAL 13
void DBlockDevice::fsTypeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 13, nullptr);
}

// SIGNAL 14
void DBlockDevice::idUUIDChanged(QString _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 14, nullptr, _t1);
}

// SIGNAL 15
void DBlockDevice::idUsageChanged(QString _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 15, nullptr, _t1);
}

// SIGNAL 16
void DBlockDevice::idVersionChanged(QString _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 16, nullptr, _t1);
}

// SIGNAL 17
void DBlockDevice::mDRaidChanged(QString _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 17, nullptr, _t1);
}

// SIGNAL 18
void DBlockDevice::mDRaidMemberChanged(QString _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 18, nullptr, _t1);
}

// SIGNAL 19
void DBlockDevice::preferredDeviceChanged(QByteArray _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 19, nullptr, _t1);
}

// SIGNAL 20
void DBlockDevice::readOnlyChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 20, nullptr, _t1);
}

// SIGNAL 21
void DBlockDevice::sizeChanged(qulonglong _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 21, nullptr, _t1);
}

// SIGNAL 22
void DBlockDevice::symlinksChanged(QByteArrayList _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 22, nullptr, _t1);
}

// SIGNAL 23
void DBlockDevice::userspaceMountOptionsChanged(QStringList _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 23, nullptr, _t1);
}

// SIGNAL 24
void DBlockDevice::ptTypeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 24, nullptr);
}

// SIGNAL 25
void DBlockDevice::mountPointsChanged(const QByteArrayList & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 25, nullptr, _t1);
}

// SIGNAL 26
void DBlockDevice::childConfigurationChanged(QList<QPair<QString,QVariantMap>> _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 26, nullptr, _t1);
}

// SIGNAL 27
void DBlockDevice::cleartextDeviceChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 27, nullptr, _t1);
}
QT_WARNING_POP
