/****************************************************************************
** Meta object code from reading C++ file 'udisks2_interface.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "udisks2_interface.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'udisks2_interface.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN35OrgFreedesktopUDisks2BlockInterfaceE_t {};
} // unnamed namespace

template <> constexpr inline auto OrgFreedesktopUDisks2BlockInterface::qt_create_metaobjectdata<qt_meta_tag_ZN35OrgFreedesktopUDisks2BlockInterfaceE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "OrgFreedesktopUDisks2BlockInterface",
        "AddConfigurationItem",
        "QDBusPendingReply<>",
        "",
        "std::pair<QString,QVariantMap>",
        "item",
        "QVariantMap",
        "options",
        "Format",
        "type",
        "GetSecretConfiguration",
        "QDBusPendingReply<QList<std::pair<QString,QVariantMap>>>",
        "OpenDevice",
        "QDBusPendingReply<QDBusUnixFileDescriptor>",
        "mode",
        "OpenForBackup",
        "OpenForBenchmark",
        "OpenForRestore",
        "RemoveConfigurationItem",
        "Rescan",
        "UpdateConfigurationItem",
        "old_item",
        "new_item",
        "Configuration",
        "QList<std::pair<QString,QVariantMap>>",
        "CryptoBackingDevice",
        "QDBusObjectPath",
        "Device",
        "DeviceNumber",
        "Drive",
        "HintAuto",
        "HintIconName",
        "HintIgnore",
        "HintName",
        "HintPartitionable",
        "HintSymbolicIconName",
        "HintSystem",
        "Id",
        "IdLabel",
        "IdType",
        "IdUUID",
        "IdUsage",
        "IdVersion",
        "MDRaid",
        "MDRaidMember",
        "PreferredDevice",
        "ReadOnly",
        "Size",
        "Symlinks",
        "QByteArrayList",
        "UserspaceMountOptions"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'AddConfigurationItem'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QPair<QString,QVariantMap> &, const QVariantMap &)>(1, 3, QMC::AccessPublic, 0x80000000 | 2, {{
            { 0x80000000 | 4, 5 }, { 0x80000000 | 6, 7 },
        }}),
        // Slot 'Format'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QString &, const QVariantMap &)>(8, 3, QMC::AccessPublic, 0x80000000 | 2, {{
            { QMetaType::QString, 9 }, { 0x80000000 | 6, 7 },
        }}),
        // Slot 'GetSecretConfiguration'
        QtMocHelpers::SlotData<QDBusPendingReply<QList<QPair<QString,QVariantMap>> >(const QVariantMap &)>(10, 3, QMC::AccessPublic, 0x80000000 | 11, {{
            { 0x80000000 | 6, 7 },
        }}),
        // Slot 'OpenDevice'
        QtMocHelpers::SlotData<QDBusPendingReply<QDBusUnixFileDescriptor>(const QString &, const QVariantMap &)>(12, 3, QMC::AccessPublic, 0x80000000 | 13, {{
            { QMetaType::QString, 14 }, { 0x80000000 | 6, 7 },
        }}),
        // Slot 'OpenForBackup'
        QtMocHelpers::SlotData<QDBusPendingReply<QDBusUnixFileDescriptor>(const QVariantMap &)>(15, 3, QMC::AccessPublic, 0x80000000 | 13, {{
            { 0x80000000 | 6, 7 },
        }}),
        // Slot 'OpenForBenchmark'
        QtMocHelpers::SlotData<QDBusPendingReply<QDBusUnixFileDescriptor>(const QVariantMap &)>(16, 3, QMC::AccessPublic, 0x80000000 | 13, {{
            { 0x80000000 | 6, 7 },
        }}),
        // Slot 'OpenForRestore'
        QtMocHelpers::SlotData<QDBusPendingReply<QDBusUnixFileDescriptor>(const QVariantMap &)>(17, 3, QMC::AccessPublic, 0x80000000 | 13, {{
            { 0x80000000 | 6, 7 },
        }}),
        // Slot 'RemoveConfigurationItem'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QPair<QString,QVariantMap> &, const QVariantMap &)>(18, 3, QMC::AccessPublic, 0x80000000 | 2, {{
            { 0x80000000 | 4, 5 }, { 0x80000000 | 6, 7 },
        }}),
        // Slot 'Rescan'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QVariantMap &)>(19, 3, QMC::AccessPublic, 0x80000000 | 2, {{
            { 0x80000000 | 6, 7 },
        }}),
        // Slot 'UpdateConfigurationItem'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QPair<QString,QVariantMap> &, const QPair<QString,QVariantMap> &, const QVariantMap &)>(20, 3, QMC::AccessPublic, 0x80000000 | 2, {{
            { 0x80000000 | 4, 21 }, { 0x80000000 | 4, 22 }, { 0x80000000 | 6, 7 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'Configuration'
        QtMocHelpers::PropertyData<QList<std::pair<QString,QVariantMap>>>(23, 0x80000000 | 24, QMC::DefaultPropertyFlags | QMC::EnumOrFlag),
        // property 'CryptoBackingDevice'
        QtMocHelpers::PropertyData<QDBusObjectPath>(25, 0x80000000 | 26, QMC::DefaultPropertyFlags | QMC::EnumOrFlag),
        // property 'Device'
        QtMocHelpers::PropertyData<QByteArray>(27, QMetaType::QByteArray, QMC::DefaultPropertyFlags),
        // property 'DeviceNumber'
        QtMocHelpers::PropertyData<qulonglong>(28, QMetaType::ULongLong, QMC::DefaultPropertyFlags),
        // property 'Drive'
        QtMocHelpers::PropertyData<QDBusObjectPath>(29, 0x80000000 | 26, QMC::DefaultPropertyFlags | QMC::EnumOrFlag),
        // property 'HintAuto'
        QtMocHelpers::PropertyData<bool>(30, QMetaType::Bool, QMC::DefaultPropertyFlags),
        // property 'HintIconName'
        QtMocHelpers::PropertyData<QString>(31, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'HintIgnore'
        QtMocHelpers::PropertyData<bool>(32, QMetaType::Bool, QMC::DefaultPropertyFlags),
        // property 'HintName'
        QtMocHelpers::PropertyData<QString>(33, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'HintPartitionable'
        QtMocHelpers::PropertyData<bool>(34, QMetaType::Bool, QMC::DefaultPropertyFlags),
        // property 'HintSymbolicIconName'
        QtMocHelpers::PropertyData<QString>(35, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'HintSystem'
        QtMocHelpers::PropertyData<bool>(36, QMetaType::Bool, QMC::DefaultPropertyFlags),
        // property 'Id'
        QtMocHelpers::PropertyData<QString>(37, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'IdLabel'
        QtMocHelpers::PropertyData<QString>(38, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'IdType'
        QtMocHelpers::PropertyData<QString>(39, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'IdUUID'
        QtMocHelpers::PropertyData<QString>(40, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'IdUsage'
        QtMocHelpers::PropertyData<QString>(41, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'IdVersion'
        QtMocHelpers::PropertyData<QString>(42, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'MDRaid'
        QtMocHelpers::PropertyData<QDBusObjectPath>(43, 0x80000000 | 26, QMC::DefaultPropertyFlags | QMC::EnumOrFlag),
        // property 'MDRaidMember'
        QtMocHelpers::PropertyData<QDBusObjectPath>(44, 0x80000000 | 26, QMC::DefaultPropertyFlags | QMC::EnumOrFlag),
        // property 'PreferredDevice'
        QtMocHelpers::PropertyData<QByteArray>(45, QMetaType::QByteArray, QMC::DefaultPropertyFlags),
        // property 'ReadOnly'
        QtMocHelpers::PropertyData<bool>(46, QMetaType::Bool, QMC::DefaultPropertyFlags),
        // property 'Size'
        QtMocHelpers::PropertyData<qulonglong>(47, QMetaType::ULongLong, QMC::DefaultPropertyFlags),
        // property 'Symlinks'
        QtMocHelpers::PropertyData<QByteArrayList>(48, 0x80000000 | 49, QMC::DefaultPropertyFlags | QMC::EnumOrFlag),
        // property 'UserspaceMountOptions'
        QtMocHelpers::PropertyData<QStringList>(50, QMetaType::QStringList, QMC::DefaultPropertyFlags),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<OrgFreedesktopUDisks2BlockInterface, qt_meta_tag_ZN35OrgFreedesktopUDisks2BlockInterfaceE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject OrgFreedesktopUDisks2BlockInterface::staticMetaObject = { {
    QMetaObject::SuperData::link<QDBusAbstractInterface::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN35OrgFreedesktopUDisks2BlockInterfaceE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN35OrgFreedesktopUDisks2BlockInterfaceE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN35OrgFreedesktopUDisks2BlockInterfaceE_t>.metaTypes,
    nullptr
} };

void OrgFreedesktopUDisks2BlockInterface::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<OrgFreedesktopUDisks2BlockInterface *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: { QDBusPendingReply<> _r = _t->AddConfigurationItem((*reinterpret_cast<std::add_pointer_t<std::pair<QString,QVariantMap>>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 1: { QDBusPendingReply<> _r = _t->Format((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 2: { QDBusPendingReply<QList<std::pair<QString,QVariantMap>>> _r = _t->GetSecretConfiguration((*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QList<std::pair<QString,QVariantMap>>>*>(_a[0]) = std::move(_r); }  break;
        case 3: { QDBusPendingReply<QDBusUnixFileDescriptor> _r = _t->OpenDevice((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QDBusUnixFileDescriptor>*>(_a[0]) = std::move(_r); }  break;
        case 4: { QDBusPendingReply<QDBusUnixFileDescriptor> _r = _t->OpenForBackup((*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QDBusUnixFileDescriptor>*>(_a[0]) = std::move(_r); }  break;
        case 5: { QDBusPendingReply<QDBusUnixFileDescriptor> _r = _t->OpenForBenchmark((*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QDBusUnixFileDescriptor>*>(_a[0]) = std::move(_r); }  break;
        case 6: { QDBusPendingReply<QDBusUnixFileDescriptor> _r = _t->OpenForRestore((*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QDBusUnixFileDescriptor>*>(_a[0]) = std::move(_r); }  break;
        case 7: { QDBusPendingReply<> _r = _t->RemoveConfigurationItem((*reinterpret_cast<std::add_pointer_t<std::pair<QString,QVariantMap>>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 8: { QDBusPendingReply<> _r = _t->Rescan((*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 9: { QDBusPendingReply<> _r = _t->UpdateConfigurationItem((*reinterpret_cast<std::add_pointer_t<std::pair<QString,QVariantMap>>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<std::pair<QString,QVariantMap>>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[3])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QList<std::pair<QString,QVariantMap>>*>(_v) = _t->configuration(); break;
        case 1: *reinterpret_cast<QDBusObjectPath*>(_v) = _t->cryptoBackingDevice(); break;
        case 2: *reinterpret_cast<QByteArray*>(_v) = _t->device(); break;
        case 3: *reinterpret_cast<qulonglong*>(_v) = _t->deviceNumber(); break;
        case 4: *reinterpret_cast<QDBusObjectPath*>(_v) = _t->drive(); break;
        case 5: *reinterpret_cast<bool*>(_v) = _t->hintAuto(); break;
        case 6: *reinterpret_cast<QString*>(_v) = _t->hintIconName(); break;
        case 7: *reinterpret_cast<bool*>(_v) = _t->hintIgnore(); break;
        case 8: *reinterpret_cast<QString*>(_v) = _t->hintName(); break;
        case 9: *reinterpret_cast<bool*>(_v) = _t->hintPartitionable(); break;
        case 10: *reinterpret_cast<QString*>(_v) = _t->hintSymbolicIconName(); break;
        case 11: *reinterpret_cast<bool*>(_v) = _t->hintSystem(); break;
        case 12: *reinterpret_cast<QString*>(_v) = _t->id(); break;
        case 13: *reinterpret_cast<QString*>(_v) = _t->idLabel(); break;
        case 14: *reinterpret_cast<QString*>(_v) = _t->idType(); break;
        case 15: *reinterpret_cast<QString*>(_v) = _t->idUUID(); break;
        case 16: *reinterpret_cast<QString*>(_v) = _t->idUsage(); break;
        case 17: *reinterpret_cast<QString*>(_v) = _t->idVersion(); break;
        case 18: *reinterpret_cast<QDBusObjectPath*>(_v) = _t->mDRaid(); break;
        case 19: *reinterpret_cast<QDBusObjectPath*>(_v) = _t->mDRaidMember(); break;
        case 20: *reinterpret_cast<QByteArray*>(_v) = _t->preferredDevice(); break;
        case 21: *reinterpret_cast<bool*>(_v) = _t->readOnly(); break;
        case 22: *reinterpret_cast<qulonglong*>(_v) = _t->size(); break;
        case 23: *reinterpret_cast<QByteArrayList*>(_v) = _t->symlinks(); break;
        case 24: *reinterpret_cast<QStringList*>(_v) = _t->userspaceMountOptions(); break;
        default: break;
        }
    }
}

const QMetaObject *OrgFreedesktopUDisks2BlockInterface::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *OrgFreedesktopUDisks2BlockInterface::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN35OrgFreedesktopUDisks2BlockInterfaceE_t>.strings))
        return static_cast<void*>(this);
    return QDBusAbstractInterface::qt_metacast(_clname);
}

int OrgFreedesktopUDisks2BlockInterface::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDBusAbstractInterface::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 10)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 10;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 10)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 10;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 25;
    }
    return _id;
}
namespace {
struct qt_meta_tag_ZN35OrgFreedesktopUDisks2DriveInterfaceE_t {};
} // unnamed namespace

template <> constexpr inline auto OrgFreedesktopUDisks2DriveInterface::qt_create_metaobjectdata<qt_meta_tag_ZN35OrgFreedesktopUDisks2DriveInterfaceE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "OrgFreedesktopUDisks2DriveInterface",
        "Eject",
        "QDBusPendingReply<>",
        "",
        "QVariantMap",
        "options",
        "PowerOff",
        "SetConfiguration",
        "value",
        "CanPowerOff",
        "Configuration",
        "ConnectionBus",
        "Ejectable",
        "Id",
        "Media",
        "MediaAvailable",
        "MediaChangeDetected",
        "MediaCompatibility",
        "MediaRemovable",
        "Model",
        "Optical",
        "OpticalBlank",
        "OpticalNumAudioTracks",
        "OpticalNumDataTracks",
        "OpticalNumSessions",
        "OpticalNumTracks",
        "Removable",
        "Revision",
        "RotationRate",
        "Seat",
        "Serial",
        "SiblingId",
        "Size",
        "SortKey",
        "TimeDetected",
        "TimeMediaDetected",
        "Vendor",
        "WWN"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'Eject'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QVariantMap &)>(1, 3, QMC::AccessPublic, 0x80000000 | 2, {{
            { 0x80000000 | 4, 5 },
        }}),
        // Slot 'PowerOff'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QVariantMap &)>(6, 3, QMC::AccessPublic, 0x80000000 | 2, {{
            { 0x80000000 | 4, 5 },
        }}),
        // Slot 'SetConfiguration'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QVariantMap &, const QVariantMap &)>(7, 3, QMC::AccessPublic, 0x80000000 | 2, {{
            { 0x80000000 | 4, 8 }, { 0x80000000 | 4, 5 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'CanPowerOff'
        QtMocHelpers::PropertyData<bool>(9, QMetaType::Bool, QMC::DefaultPropertyFlags),
        // property 'Configuration'
        QtMocHelpers::PropertyData<QVariantMap>(10, 0x80000000 | 4, QMC::DefaultPropertyFlags | QMC::EnumOrFlag),
        // property 'ConnectionBus'
        QtMocHelpers::PropertyData<QString>(11, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'Ejectable'
        QtMocHelpers::PropertyData<bool>(12, QMetaType::Bool, QMC::DefaultPropertyFlags),
        // property 'Id'
        QtMocHelpers::PropertyData<QString>(13, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'Media'
        QtMocHelpers::PropertyData<QString>(14, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'MediaAvailable'
        QtMocHelpers::PropertyData<bool>(15, QMetaType::Bool, QMC::DefaultPropertyFlags),
        // property 'MediaChangeDetected'
        QtMocHelpers::PropertyData<bool>(16, QMetaType::Bool, QMC::DefaultPropertyFlags),
        // property 'MediaCompatibility'
        QtMocHelpers::PropertyData<QStringList>(17, QMetaType::QStringList, QMC::DefaultPropertyFlags),
        // property 'MediaRemovable'
        QtMocHelpers::PropertyData<bool>(18, QMetaType::Bool, QMC::DefaultPropertyFlags),
        // property 'Model'
        QtMocHelpers::PropertyData<QString>(19, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'Optical'
        QtMocHelpers::PropertyData<bool>(20, QMetaType::Bool, QMC::DefaultPropertyFlags),
        // property 'OpticalBlank'
        QtMocHelpers::PropertyData<bool>(21, QMetaType::Bool, QMC::DefaultPropertyFlags),
        // property 'OpticalNumAudioTracks'
        QtMocHelpers::PropertyData<uint>(22, QMetaType::UInt, QMC::DefaultPropertyFlags),
        // property 'OpticalNumDataTracks'
        QtMocHelpers::PropertyData<uint>(23, QMetaType::UInt, QMC::DefaultPropertyFlags),
        // property 'OpticalNumSessions'
        QtMocHelpers::PropertyData<uint>(24, QMetaType::UInt, QMC::DefaultPropertyFlags),
        // property 'OpticalNumTracks'
        QtMocHelpers::PropertyData<uint>(25, QMetaType::UInt, QMC::DefaultPropertyFlags),
        // property 'Removable'
        QtMocHelpers::PropertyData<bool>(26, QMetaType::Bool, QMC::DefaultPropertyFlags),
        // property 'Revision'
        QtMocHelpers::PropertyData<QString>(27, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'RotationRate'
        QtMocHelpers::PropertyData<int>(28, QMetaType::Int, QMC::DefaultPropertyFlags),
        // property 'Seat'
        QtMocHelpers::PropertyData<QString>(29, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'Serial'
        QtMocHelpers::PropertyData<QString>(30, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'SiblingId'
        QtMocHelpers::PropertyData<QString>(31, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'Size'
        QtMocHelpers::PropertyData<qulonglong>(32, QMetaType::ULongLong, QMC::DefaultPropertyFlags),
        // property 'SortKey'
        QtMocHelpers::PropertyData<QString>(33, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'TimeDetected'
        QtMocHelpers::PropertyData<qulonglong>(34, QMetaType::ULongLong, QMC::DefaultPropertyFlags),
        // property 'TimeMediaDetected'
        QtMocHelpers::PropertyData<qulonglong>(35, QMetaType::ULongLong, QMC::DefaultPropertyFlags),
        // property 'Vendor'
        QtMocHelpers::PropertyData<QString>(36, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'WWN'
        QtMocHelpers::PropertyData<QString>(37, QMetaType::QString, QMC::DefaultPropertyFlags),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<OrgFreedesktopUDisks2DriveInterface, qt_meta_tag_ZN35OrgFreedesktopUDisks2DriveInterfaceE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject OrgFreedesktopUDisks2DriveInterface::staticMetaObject = { {
    QMetaObject::SuperData::link<QDBusAbstractInterface::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN35OrgFreedesktopUDisks2DriveInterfaceE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN35OrgFreedesktopUDisks2DriveInterfaceE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN35OrgFreedesktopUDisks2DriveInterfaceE_t>.metaTypes,
    nullptr
} };

void OrgFreedesktopUDisks2DriveInterface::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<OrgFreedesktopUDisks2DriveInterface *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: { QDBusPendingReply<> _r = _t->Eject((*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 1: { QDBusPendingReply<> _r = _t->PowerOff((*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 2: { QDBusPendingReply<> _r = _t->SetConfiguration((*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<bool*>(_v) = _t->canPowerOff(); break;
        case 1: *reinterpret_cast<QVariantMap*>(_v) = _t->configuration(); break;
        case 2: *reinterpret_cast<QString*>(_v) = _t->connectionBus(); break;
        case 3: *reinterpret_cast<bool*>(_v) = _t->ejectable(); break;
        case 4: *reinterpret_cast<QString*>(_v) = _t->id(); break;
        case 5: *reinterpret_cast<QString*>(_v) = _t->media(); break;
        case 6: *reinterpret_cast<bool*>(_v) = _t->mediaAvailable(); break;
        case 7: *reinterpret_cast<bool*>(_v) = _t->mediaChangeDetected(); break;
        case 8: *reinterpret_cast<QStringList*>(_v) = _t->mediaCompatibility(); break;
        case 9: *reinterpret_cast<bool*>(_v) = _t->mediaRemovable(); break;
        case 10: *reinterpret_cast<QString*>(_v) = _t->model(); break;
        case 11: *reinterpret_cast<bool*>(_v) = _t->optical(); break;
        case 12: *reinterpret_cast<bool*>(_v) = _t->opticalBlank(); break;
        case 13: *reinterpret_cast<uint*>(_v) = _t->opticalNumAudioTracks(); break;
        case 14: *reinterpret_cast<uint*>(_v) = _t->opticalNumDataTracks(); break;
        case 15: *reinterpret_cast<uint*>(_v) = _t->opticalNumSessions(); break;
        case 16: *reinterpret_cast<uint*>(_v) = _t->opticalNumTracks(); break;
        case 17: *reinterpret_cast<bool*>(_v) = _t->removable(); break;
        case 18: *reinterpret_cast<QString*>(_v) = _t->revision(); break;
        case 19: *reinterpret_cast<int*>(_v) = _t->rotationRate(); break;
        case 20: *reinterpret_cast<QString*>(_v) = _t->seat(); break;
        case 21: *reinterpret_cast<QString*>(_v) = _t->serial(); break;
        case 22: *reinterpret_cast<QString*>(_v) = _t->siblingId(); break;
        case 23: *reinterpret_cast<qulonglong*>(_v) = _t->size(); break;
        case 24: *reinterpret_cast<QString*>(_v) = _t->sortKey(); break;
        case 25: *reinterpret_cast<qulonglong*>(_v) = _t->timeDetected(); break;
        case 26: *reinterpret_cast<qulonglong*>(_v) = _t->timeMediaDetected(); break;
        case 27: *reinterpret_cast<QString*>(_v) = _t->vendor(); break;
        case 28: *reinterpret_cast<QString*>(_v) = _t->wWN(); break;
        default: break;
        }
    }
}

const QMetaObject *OrgFreedesktopUDisks2DriveInterface::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *OrgFreedesktopUDisks2DriveInterface::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN35OrgFreedesktopUDisks2DriveInterfaceE_t>.strings))
        return static_cast<void*>(this);
    return QDBusAbstractInterface::qt_metacast(_clname);
}

int OrgFreedesktopUDisks2DriveInterface::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDBusAbstractInterface::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 3)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 3)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 3;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 29;
    }
    return _id;
}
namespace {
struct qt_meta_tag_ZN38OrgFreedesktopUDisks2DriveAtaInterfaceE_t {};
} // unnamed namespace

template <> constexpr inline auto OrgFreedesktopUDisks2DriveAtaInterface::qt_create_metaobjectdata<qt_meta_tag_ZN38OrgFreedesktopUDisks2DriveAtaInterfaceE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "OrgFreedesktopUDisks2DriveAtaInterface",
        "PmGetState",
        "QDBusPendingReply<uchar>",
        "",
        "QVariantMap",
        "options",
        "PmStandby",
        "QDBusPendingReply<>",
        "PmWakeup",
        "SecurityEraseUnit",
        "SmartGetAttributes",
        "QDBusPendingReply<QList<UDisks2::SmartAttribute>>",
        "SmartSelftestAbort",
        "SmartSelftestStart",
        "type",
        "SmartSetEnabled",
        "value",
        "SmartUpdate",
        "AamEnabled",
        "AamSupported",
        "AamVendorRecommendedValue",
        "ApmEnabled",
        "ApmSupported",
        "PmEnabled",
        "PmSupported",
        "ReadLookaheadEnabled",
        "ReadLookaheadSupported",
        "SecurityEnhancedEraseUnitMinutes",
        "SecurityEraseUnitMinutes",
        "SecurityFrozen",
        "SmartEnabled",
        "SmartFailing",
        "SmartNumAttributesFailedInThePast",
        "SmartNumAttributesFailing",
        "SmartNumBadSectors",
        "SmartPowerOnSeconds",
        "SmartSelftestPercentRemaining",
        "SmartSelftestStatus",
        "SmartSupported",
        "SmartTemperature",
        "SmartUpdated",
        "WriteCacheEnabled",
        "WriteCacheSupported"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'PmGetState'
        QtMocHelpers::SlotData<QDBusPendingReply<uchar>(const QVariantMap &)>(1, 3, QMC::AccessPublic, 0x80000000 | 2, {{
            { 0x80000000 | 4, 5 },
        }}),
        // Slot 'PmStandby'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QVariantMap &)>(6, 3, QMC::AccessPublic, 0x80000000 | 7, {{
            { 0x80000000 | 4, 5 },
        }}),
        // Slot 'PmWakeup'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QVariantMap &)>(8, 3, QMC::AccessPublic, 0x80000000 | 7, {{
            { 0x80000000 | 4, 5 },
        }}),
        // Slot 'SecurityEraseUnit'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QVariantMap &)>(9, 3, QMC::AccessPublic, 0x80000000 | 7, {{
            { 0x80000000 | 4, 5 },
        }}),
        // Slot 'SmartGetAttributes'
        QtMocHelpers::SlotData<QDBusPendingReply<QList<UDisks2::SmartAttribute> >(const QVariantMap &)>(10, 3, QMC::AccessPublic, 0x80000000 | 11, {{
            { 0x80000000 | 4, 5 },
        }}),
        // Slot 'SmartSelftestAbort'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QVariantMap &)>(12, 3, QMC::AccessPublic, 0x80000000 | 7, {{
            { 0x80000000 | 4, 5 },
        }}),
        // Slot 'SmartSelftestStart'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QString &, const QVariantMap &)>(13, 3, QMC::AccessPublic, 0x80000000 | 7, {{
            { QMetaType::QString, 14 }, { 0x80000000 | 4, 5 },
        }}),
        // Slot 'SmartSetEnabled'
        QtMocHelpers::SlotData<QDBusPendingReply<>(bool, const QVariantMap &)>(15, 3, QMC::AccessPublic, 0x80000000 | 7, {{
            { QMetaType::Bool, 16 }, { 0x80000000 | 4, 5 },
        }}),
        // Slot 'SmartUpdate'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QVariantMap &)>(17, 3, QMC::AccessPublic, 0x80000000 | 7, {{
            { 0x80000000 | 4, 5 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'AamEnabled'
        QtMocHelpers::PropertyData<bool>(18, QMetaType::Bool, QMC::DefaultPropertyFlags),
        // property 'AamSupported'
        QtMocHelpers::PropertyData<bool>(19, QMetaType::Bool, QMC::DefaultPropertyFlags),
        // property 'AamVendorRecommendedValue'
        QtMocHelpers::PropertyData<int>(20, QMetaType::Int, QMC::DefaultPropertyFlags),
        // property 'ApmEnabled'
        QtMocHelpers::PropertyData<bool>(21, QMetaType::Bool, QMC::DefaultPropertyFlags),
        // property 'ApmSupported'
        QtMocHelpers::PropertyData<bool>(22, QMetaType::Bool, QMC::DefaultPropertyFlags),
        // property 'PmEnabled'
        QtMocHelpers::PropertyData<bool>(23, QMetaType::Bool, QMC::DefaultPropertyFlags),
        // property 'PmSupported'
        QtMocHelpers::PropertyData<bool>(24, QMetaType::Bool, QMC::DefaultPropertyFlags),
        // property 'ReadLookaheadEnabled'
        QtMocHelpers::PropertyData<bool>(25, QMetaType::Bool, QMC::DefaultPropertyFlags),
        // property 'ReadLookaheadSupported'
        QtMocHelpers::PropertyData<bool>(26, QMetaType::Bool, QMC::DefaultPropertyFlags),
        // property 'SecurityEnhancedEraseUnitMinutes'
        QtMocHelpers::PropertyData<int>(27, QMetaType::Int, QMC::DefaultPropertyFlags),
        // property 'SecurityEraseUnitMinutes'
        QtMocHelpers::PropertyData<int>(28, QMetaType::Int, QMC::DefaultPropertyFlags),
        // property 'SecurityFrozen'
        QtMocHelpers::PropertyData<bool>(29, QMetaType::Bool, QMC::DefaultPropertyFlags),
        // property 'SmartEnabled'
        QtMocHelpers::PropertyData<bool>(30, QMetaType::Bool, QMC::DefaultPropertyFlags),
        // property 'SmartFailing'
        QtMocHelpers::PropertyData<bool>(31, QMetaType::Bool, QMC::DefaultPropertyFlags),
        // property 'SmartNumAttributesFailedInThePast'
        QtMocHelpers::PropertyData<int>(32, QMetaType::Int, QMC::DefaultPropertyFlags),
        // property 'SmartNumAttributesFailing'
        QtMocHelpers::PropertyData<int>(33, QMetaType::Int, QMC::DefaultPropertyFlags),
        // property 'SmartNumBadSectors'
        QtMocHelpers::PropertyData<qlonglong>(34, QMetaType::LongLong, QMC::DefaultPropertyFlags),
        // property 'SmartPowerOnSeconds'
        QtMocHelpers::PropertyData<qulonglong>(35, QMetaType::ULongLong, QMC::DefaultPropertyFlags),
        // property 'SmartSelftestPercentRemaining'
        QtMocHelpers::PropertyData<int>(36, QMetaType::Int, QMC::DefaultPropertyFlags),
        // property 'SmartSelftestStatus'
        QtMocHelpers::PropertyData<QString>(37, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'SmartSupported'
        QtMocHelpers::PropertyData<bool>(38, QMetaType::Bool, QMC::DefaultPropertyFlags),
        // property 'SmartTemperature'
        QtMocHelpers::PropertyData<double>(39, QMetaType::Double, QMC::DefaultPropertyFlags),
        // property 'SmartUpdated'
        QtMocHelpers::PropertyData<qulonglong>(40, QMetaType::ULongLong, QMC::DefaultPropertyFlags),
        // property 'WriteCacheEnabled'
        QtMocHelpers::PropertyData<bool>(41, QMetaType::Bool, QMC::DefaultPropertyFlags),
        // property 'WriteCacheSupported'
        QtMocHelpers::PropertyData<bool>(42, QMetaType::Bool, QMC::DefaultPropertyFlags),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<OrgFreedesktopUDisks2DriveAtaInterface, qt_meta_tag_ZN38OrgFreedesktopUDisks2DriveAtaInterfaceE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject OrgFreedesktopUDisks2DriveAtaInterface::staticMetaObject = { {
    QMetaObject::SuperData::link<QDBusAbstractInterface::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN38OrgFreedesktopUDisks2DriveAtaInterfaceE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN38OrgFreedesktopUDisks2DriveAtaInterfaceE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN38OrgFreedesktopUDisks2DriveAtaInterfaceE_t>.metaTypes,
    nullptr
} };

void OrgFreedesktopUDisks2DriveAtaInterface::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<OrgFreedesktopUDisks2DriveAtaInterface *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: { QDBusPendingReply<uchar> _r = _t->PmGetState((*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<uchar>*>(_a[0]) = std::move(_r); }  break;
        case 1: { QDBusPendingReply<> _r = _t->PmStandby((*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 2: { QDBusPendingReply<> _r = _t->PmWakeup((*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 3: { QDBusPendingReply<> _r = _t->SecurityEraseUnit((*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 4: { QDBusPendingReply<QList<UDisks2::SmartAttribute>> _r = _t->SmartGetAttributes((*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QList<UDisks2::SmartAttribute>>*>(_a[0]) = std::move(_r); }  break;
        case 5: { QDBusPendingReply<> _r = _t->SmartSelftestAbort((*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 6: { QDBusPendingReply<> _r = _t->SmartSelftestStart((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 7: { QDBusPendingReply<> _r = _t->SmartSetEnabled((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 8: { QDBusPendingReply<> _r = _t->SmartUpdate((*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<bool*>(_v) = _t->aamEnabled(); break;
        case 1: *reinterpret_cast<bool*>(_v) = _t->aamSupported(); break;
        case 2: *reinterpret_cast<int*>(_v) = _t->aamVendorRecommendedValue(); break;
        case 3: *reinterpret_cast<bool*>(_v) = _t->apmEnabled(); break;
        case 4: *reinterpret_cast<bool*>(_v) = _t->apmSupported(); break;
        case 5: *reinterpret_cast<bool*>(_v) = _t->pmEnabled(); break;
        case 6: *reinterpret_cast<bool*>(_v) = _t->pmSupported(); break;
        case 7: *reinterpret_cast<bool*>(_v) = _t->readLookaheadEnabled(); break;
        case 8: *reinterpret_cast<bool*>(_v) = _t->readLookaheadSupported(); break;
        case 9: *reinterpret_cast<int*>(_v) = _t->securityEnhancedEraseUnitMinutes(); break;
        case 10: *reinterpret_cast<int*>(_v) = _t->securityEraseUnitMinutes(); break;
        case 11: *reinterpret_cast<bool*>(_v) = _t->securityFrozen(); break;
        case 12: *reinterpret_cast<bool*>(_v) = _t->smartEnabled(); break;
        case 13: *reinterpret_cast<bool*>(_v) = _t->smartFailing(); break;
        case 14: *reinterpret_cast<int*>(_v) = _t->smartNumAttributesFailedInThePast(); break;
        case 15: *reinterpret_cast<int*>(_v) = _t->smartNumAttributesFailing(); break;
        case 16: *reinterpret_cast<qlonglong*>(_v) = _t->smartNumBadSectors(); break;
        case 17: *reinterpret_cast<qulonglong*>(_v) = _t->smartPowerOnSeconds(); break;
        case 18: *reinterpret_cast<int*>(_v) = _t->smartSelftestPercentRemaining(); break;
        case 19: *reinterpret_cast<QString*>(_v) = _t->smartSelftestStatus(); break;
        case 20: *reinterpret_cast<bool*>(_v) = _t->smartSupported(); break;
        case 21: *reinterpret_cast<double*>(_v) = _t->smartTemperature(); break;
        case 22: *reinterpret_cast<qulonglong*>(_v) = _t->smartUpdated(); break;
        case 23: *reinterpret_cast<bool*>(_v) = _t->writeCacheEnabled(); break;
        case 24: *reinterpret_cast<bool*>(_v) = _t->writeCacheSupported(); break;
        default: break;
        }
    }
}

const QMetaObject *OrgFreedesktopUDisks2DriveAtaInterface::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *OrgFreedesktopUDisks2DriveAtaInterface::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN38OrgFreedesktopUDisks2DriveAtaInterfaceE_t>.strings))
        return static_cast<void*>(this);
    return QDBusAbstractInterface::qt_metacast(_clname);
}

int OrgFreedesktopUDisks2DriveAtaInterface::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDBusAbstractInterface::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 9)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 9)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 9;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 25;
    }
    return _id;
}
namespace {
struct qt_meta_tag_ZN39OrgFreedesktopUDisks2EncryptedInterfaceE_t {};
} // unnamed namespace

template <> constexpr inline auto OrgFreedesktopUDisks2EncryptedInterface::qt_create_metaobjectdata<qt_meta_tag_ZN39OrgFreedesktopUDisks2EncryptedInterfaceE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "OrgFreedesktopUDisks2EncryptedInterface",
        "ChangePassphrase",
        "QDBusPendingReply<>",
        "",
        "passphrase",
        "new_passphrase",
        "QVariantMap",
        "options",
        "Lock",
        "Resize",
        "size",
        "Unlock",
        "QDBusPendingReply<QDBusObjectPath>",
        "ChildConfiguration",
        "QList<std::pair<QString,QVariantMap>>",
        "CleartextDevice",
        "QDBusObjectPath",
        "HintEncryptionType",
        "MetadataSize"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'ChangePassphrase'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QString &, const QString &, const QVariantMap &)>(1, 3, QMC::AccessPublic, 0x80000000 | 2, {{
            { QMetaType::QString, 4 }, { QMetaType::QString, 5 }, { 0x80000000 | 6, 7 },
        }}),
        // Slot 'Lock'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QVariantMap &)>(8, 3, QMC::AccessPublic, 0x80000000 | 2, {{
            { 0x80000000 | 6, 7 },
        }}),
        // Slot 'Resize'
        QtMocHelpers::SlotData<QDBusPendingReply<>(qulonglong, const QVariantMap &)>(9, 3, QMC::AccessPublic, 0x80000000 | 2, {{
            { QMetaType::ULongLong, 10 }, { 0x80000000 | 6, 7 },
        }}),
        // Slot 'Unlock'
        QtMocHelpers::SlotData<QDBusPendingReply<QDBusObjectPath>(const QString &, const QVariantMap &)>(11, 3, QMC::AccessPublic, 0x80000000 | 12, {{
            { QMetaType::QString, 4 }, { 0x80000000 | 6, 7 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'ChildConfiguration'
        QtMocHelpers::PropertyData<QList<std::pair<QString,QVariantMap>>>(13, 0x80000000 | 14, QMC::DefaultPropertyFlags | QMC::EnumOrFlag),
        // property 'CleartextDevice'
        QtMocHelpers::PropertyData<QDBusObjectPath>(15, 0x80000000 | 16, QMC::DefaultPropertyFlags | QMC::EnumOrFlag),
        // property 'HintEncryptionType'
        QtMocHelpers::PropertyData<QString>(17, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'MetadataSize'
        QtMocHelpers::PropertyData<qulonglong>(18, QMetaType::ULongLong, QMC::DefaultPropertyFlags),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<OrgFreedesktopUDisks2EncryptedInterface, qt_meta_tag_ZN39OrgFreedesktopUDisks2EncryptedInterfaceE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject OrgFreedesktopUDisks2EncryptedInterface::staticMetaObject = { {
    QMetaObject::SuperData::link<QDBusAbstractInterface::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN39OrgFreedesktopUDisks2EncryptedInterfaceE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN39OrgFreedesktopUDisks2EncryptedInterfaceE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN39OrgFreedesktopUDisks2EncryptedInterfaceE_t>.metaTypes,
    nullptr
} };

void OrgFreedesktopUDisks2EncryptedInterface::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<OrgFreedesktopUDisks2EncryptedInterface *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: { QDBusPendingReply<> _r = _t->ChangePassphrase((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[3])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 1: { QDBusPendingReply<> _r = _t->Lock((*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 2: { QDBusPendingReply<> _r = _t->Resize((*reinterpret_cast<std::add_pointer_t<qulonglong>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 3: { QDBusPendingReply<QDBusObjectPath> _r = _t->Unlock((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QDBusObjectPath>*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QList<std::pair<QString,QVariantMap>>*>(_v) = _t->childConfiguration(); break;
        case 1: *reinterpret_cast<QDBusObjectPath*>(_v) = _t->cleartextDevice(); break;
        case 2: *reinterpret_cast<QString*>(_v) = _t->hintEncryptionType(); break;
        case 3: *reinterpret_cast<qulonglong*>(_v) = _t->metadataSize(); break;
        default: break;
        }
    }
}

const QMetaObject *OrgFreedesktopUDisks2EncryptedInterface::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *OrgFreedesktopUDisks2EncryptedInterface::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN39OrgFreedesktopUDisks2EncryptedInterfaceE_t>.strings))
        return static_cast<void*>(this);
    return QDBusAbstractInterface::qt_metacast(_clname);
}

int OrgFreedesktopUDisks2EncryptedInterface::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDBusAbstractInterface::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 4)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 4)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 4;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    }
    return _id;
}
namespace {
struct qt_meta_tag_ZN40OrgFreedesktopUDisks2FilesystemInterfaceE_t {};
} // unnamed namespace

template <> constexpr inline auto OrgFreedesktopUDisks2FilesystemInterface::qt_create_metaobjectdata<qt_meta_tag_ZN40OrgFreedesktopUDisks2FilesystemInterfaceE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "OrgFreedesktopUDisks2FilesystemInterface",
        "Check",
        "QDBusPendingReply<bool>",
        "",
        "QVariantMap",
        "options",
        "Mount",
        "QDBusPendingReply<QString>",
        "Repair",
        "Resize",
        "QDBusPendingReply<>",
        "size",
        "SetLabel",
        "label",
        "TakeOwnership",
        "Unmount",
        "MountPoints",
        "QByteArrayList",
        "Size"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'Check'
        QtMocHelpers::SlotData<QDBusPendingReply<bool>(const QVariantMap &)>(1, 3, QMC::AccessPublic, 0x80000000 | 2, {{
            { 0x80000000 | 4, 5 },
        }}),
        // Slot 'Mount'
        QtMocHelpers::SlotData<QDBusPendingReply<QString>(const QVariantMap &)>(6, 3, QMC::AccessPublic, 0x80000000 | 7, {{
            { 0x80000000 | 4, 5 },
        }}),
        // Slot 'Repair'
        QtMocHelpers::SlotData<QDBusPendingReply<bool>(const QVariantMap &)>(8, 3, QMC::AccessPublic, 0x80000000 | 2, {{
            { 0x80000000 | 4, 5 },
        }}),
        // Slot 'Resize'
        QtMocHelpers::SlotData<QDBusPendingReply<>(qulonglong, const QVariantMap &)>(9, 3, QMC::AccessPublic, 0x80000000 | 10, {{
            { QMetaType::ULongLong, 11 }, { 0x80000000 | 4, 5 },
        }}),
        // Slot 'SetLabel'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QString &, const QVariantMap &)>(12, 3, QMC::AccessPublic, 0x80000000 | 10, {{
            { QMetaType::QString, 13 }, { 0x80000000 | 4, 5 },
        }}),
        // Slot 'TakeOwnership'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QVariantMap &)>(14, 3, QMC::AccessPublic, 0x80000000 | 10, {{
            { 0x80000000 | 4, 5 },
        }}),
        // Slot 'Unmount'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QVariantMap &)>(15, 3, QMC::AccessPublic, 0x80000000 | 10, {{
            { 0x80000000 | 4, 5 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'MountPoints'
        QtMocHelpers::PropertyData<QByteArrayList>(16, 0x80000000 | 17, QMC::DefaultPropertyFlags | QMC::EnumOrFlag),
        // property 'Size'
        QtMocHelpers::PropertyData<qulonglong>(18, QMetaType::ULongLong, QMC::DefaultPropertyFlags),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<OrgFreedesktopUDisks2FilesystemInterface, qt_meta_tag_ZN40OrgFreedesktopUDisks2FilesystemInterfaceE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject OrgFreedesktopUDisks2FilesystemInterface::staticMetaObject = { {
    QMetaObject::SuperData::link<QDBusAbstractInterface::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN40OrgFreedesktopUDisks2FilesystemInterfaceE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN40OrgFreedesktopUDisks2FilesystemInterfaceE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN40OrgFreedesktopUDisks2FilesystemInterfaceE_t>.metaTypes,
    nullptr
} };

void OrgFreedesktopUDisks2FilesystemInterface::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<OrgFreedesktopUDisks2FilesystemInterface *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: { QDBusPendingReply<bool> _r = _t->Check((*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<bool>*>(_a[0]) = std::move(_r); }  break;
        case 1: { QDBusPendingReply<QString> _r = _t->Mount((*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QString>*>(_a[0]) = std::move(_r); }  break;
        case 2: { QDBusPendingReply<bool> _r = _t->Repair((*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<bool>*>(_a[0]) = std::move(_r); }  break;
        case 3: { QDBusPendingReply<> _r = _t->Resize((*reinterpret_cast<std::add_pointer_t<qulonglong>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 4: { QDBusPendingReply<> _r = _t->SetLabel((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 5: { QDBusPendingReply<> _r = _t->TakeOwnership((*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 6: { QDBusPendingReply<> _r = _t->Unmount((*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QByteArrayList*>(_v) = _t->mountPoints(); break;
        case 1: *reinterpret_cast<qulonglong*>(_v) = _t->size(); break;
        default: break;
        }
    }
}

const QMetaObject *OrgFreedesktopUDisks2FilesystemInterface::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *OrgFreedesktopUDisks2FilesystemInterface::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN40OrgFreedesktopUDisks2FilesystemInterfaceE_t>.strings))
        return static_cast<void*>(this);
    return QDBusAbstractInterface::qt_metacast(_clname);
}

int OrgFreedesktopUDisks2FilesystemInterface::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDBusAbstractInterface::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 7)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 7)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 7;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    }
    return _id;
}
namespace {
struct qt_meta_tag_ZN33OrgFreedesktopUDisks2JobInterfaceE_t {};
} // unnamed namespace

template <> constexpr inline auto OrgFreedesktopUDisks2JobInterface::qt_create_metaobjectdata<qt_meta_tag_ZN33OrgFreedesktopUDisks2JobInterfaceE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "OrgFreedesktopUDisks2JobInterface",
        "Completed",
        "",
        "success",
        "message",
        "Cancel",
        "QDBusPendingReply<>",
        "QVariantMap",
        "options",
        "Bytes",
        "Cancelable",
        "ExpectedEndTime",
        "Objects",
        "QList<QDBusObjectPath>",
        "Operation",
        "Progress",
        "ProgressValid",
        "Rate",
        "StartTime",
        "StartedByUID"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'Completed'
        QtMocHelpers::SignalData<void(bool, const QString &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 3 }, { QMetaType::QString, 4 },
        }}),
        // Slot 'Cancel'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QVariantMap &)>(5, 2, QMC::AccessPublic, 0x80000000 | 6, {{
            { 0x80000000 | 7, 8 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'Bytes'
        QtMocHelpers::PropertyData<qulonglong>(9, QMetaType::ULongLong, QMC::DefaultPropertyFlags),
        // property 'Cancelable'
        QtMocHelpers::PropertyData<bool>(10, QMetaType::Bool, QMC::DefaultPropertyFlags),
        // property 'ExpectedEndTime'
        QtMocHelpers::PropertyData<qulonglong>(11, QMetaType::ULongLong, QMC::DefaultPropertyFlags),
        // property 'Objects'
        QtMocHelpers::PropertyData<QList<QDBusObjectPath>>(12, 0x80000000 | 13, QMC::DefaultPropertyFlags | QMC::EnumOrFlag),
        // property 'Operation'
        QtMocHelpers::PropertyData<QString>(14, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'Progress'
        QtMocHelpers::PropertyData<double>(15, QMetaType::Double, QMC::DefaultPropertyFlags),
        // property 'ProgressValid'
        QtMocHelpers::PropertyData<bool>(16, QMetaType::Bool, QMC::DefaultPropertyFlags),
        // property 'Rate'
        QtMocHelpers::PropertyData<qulonglong>(17, QMetaType::ULongLong, QMC::DefaultPropertyFlags),
        // property 'StartTime'
        QtMocHelpers::PropertyData<qulonglong>(18, QMetaType::ULongLong, QMC::DefaultPropertyFlags),
        // property 'StartedByUID'
        QtMocHelpers::PropertyData<uint>(19, QMetaType::UInt, QMC::DefaultPropertyFlags),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<OrgFreedesktopUDisks2JobInterface, qt_meta_tag_ZN33OrgFreedesktopUDisks2JobInterfaceE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject OrgFreedesktopUDisks2JobInterface::staticMetaObject = { {
    QMetaObject::SuperData::link<QDBusAbstractInterface::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN33OrgFreedesktopUDisks2JobInterfaceE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN33OrgFreedesktopUDisks2JobInterfaceE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN33OrgFreedesktopUDisks2JobInterfaceE_t>.metaTypes,
    nullptr
} };

void OrgFreedesktopUDisks2JobInterface::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<OrgFreedesktopUDisks2JobInterface *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->Completed((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 1: { QDBusPendingReply<> _r = _t->Cancel((*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (OrgFreedesktopUDisks2JobInterface::*)(bool , const QString & )>(_a, &OrgFreedesktopUDisks2JobInterface::Completed, 0))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<qulonglong*>(_v) = _t->bytes(); break;
        case 1: *reinterpret_cast<bool*>(_v) = _t->cancelable(); break;
        case 2: *reinterpret_cast<qulonglong*>(_v) = _t->expectedEndTime(); break;
        case 3: *reinterpret_cast<QList<QDBusObjectPath>*>(_v) = _t->objects(); break;
        case 4: *reinterpret_cast<QString*>(_v) = _t->operation(); break;
        case 5: *reinterpret_cast<double*>(_v) = _t->progress(); break;
        case 6: *reinterpret_cast<bool*>(_v) = _t->progressValid(); break;
        case 7: *reinterpret_cast<qulonglong*>(_v) = _t->rate(); break;
        case 8: *reinterpret_cast<qulonglong*>(_v) = _t->startTime(); break;
        case 9: *reinterpret_cast<uint*>(_v) = _t->startedByUID(); break;
        default: break;
        }
    }
}

const QMetaObject *OrgFreedesktopUDisks2JobInterface::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *OrgFreedesktopUDisks2JobInterface::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN33OrgFreedesktopUDisks2JobInterfaceE_t>.strings))
        return static_cast<void*>(this);
    return QDBusAbstractInterface::qt_metacast(_clname);
}

int OrgFreedesktopUDisks2JobInterface::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDBusAbstractInterface::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 2)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 2)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 2;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 10;
    }
    return _id;
}

// SIGNAL 0
void OrgFreedesktopUDisks2JobInterface::Completed(bool _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2);
}
namespace {
struct qt_meta_tag_ZN34OrgFreedesktopUDisks2LoopInterfaceE_t {};
} // unnamed namespace

template <> constexpr inline auto OrgFreedesktopUDisks2LoopInterface::qt_create_metaobjectdata<qt_meta_tag_ZN34OrgFreedesktopUDisks2LoopInterfaceE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "OrgFreedesktopUDisks2LoopInterface",
        "Delete",
        "QDBusPendingReply<>",
        "",
        "QVariantMap",
        "options",
        "SetAutoclear",
        "value",
        "Autoclear",
        "BackingFile",
        "SetupByUID"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'Delete'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QVariantMap &)>(1, 3, QMC::AccessPublic, 0x80000000 | 2, {{
            { 0x80000000 | 4, 5 },
        }}),
        // Slot 'SetAutoclear'
        QtMocHelpers::SlotData<QDBusPendingReply<>(bool, const QVariantMap &)>(6, 3, QMC::AccessPublic, 0x80000000 | 2, {{
            { QMetaType::Bool, 7 }, { 0x80000000 | 4, 5 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'Autoclear'
        QtMocHelpers::PropertyData<bool>(8, QMetaType::Bool, QMC::DefaultPropertyFlags),
        // property 'BackingFile'
        QtMocHelpers::PropertyData<QByteArray>(9, QMetaType::QByteArray, QMC::DefaultPropertyFlags),
        // property 'SetupByUID'
        QtMocHelpers::PropertyData<uint>(10, QMetaType::UInt, QMC::DefaultPropertyFlags),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<OrgFreedesktopUDisks2LoopInterface, qt_meta_tag_ZN34OrgFreedesktopUDisks2LoopInterfaceE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject OrgFreedesktopUDisks2LoopInterface::staticMetaObject = { {
    QMetaObject::SuperData::link<QDBusAbstractInterface::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN34OrgFreedesktopUDisks2LoopInterfaceE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN34OrgFreedesktopUDisks2LoopInterfaceE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN34OrgFreedesktopUDisks2LoopInterfaceE_t>.metaTypes,
    nullptr
} };

void OrgFreedesktopUDisks2LoopInterface::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<OrgFreedesktopUDisks2LoopInterface *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: { QDBusPendingReply<> _r = _t->Delete((*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 1: { QDBusPendingReply<> _r = _t->SetAutoclear((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<bool*>(_v) = _t->autoclear(); break;
        case 1: *reinterpret_cast<QByteArray*>(_v) = _t->backingFile(); break;
        case 2: *reinterpret_cast<uint*>(_v) = _t->setupByUID(); break;
        default: break;
        }
    }
}

const QMetaObject *OrgFreedesktopUDisks2LoopInterface::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *OrgFreedesktopUDisks2LoopInterface::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN34OrgFreedesktopUDisks2LoopInterfaceE_t>.strings))
        return static_cast<void*>(this);
    return QDBusAbstractInterface::qt_metacast(_clname);
}

int OrgFreedesktopUDisks2LoopInterface::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDBusAbstractInterface::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 2)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 2)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 2;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    }
    return _id;
}
namespace {
struct qt_meta_tag_ZN36OrgFreedesktopUDisks2MDRaidInterfaceE_t {};
} // unnamed namespace

template <> constexpr inline auto OrgFreedesktopUDisks2MDRaidInterface::qt_create_metaobjectdata<qt_meta_tag_ZN36OrgFreedesktopUDisks2MDRaidInterfaceE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "OrgFreedesktopUDisks2MDRaidInterface",
        "AddDevice",
        "QDBusPendingReply<>",
        "",
        "QDBusObjectPath",
        "device",
        "QVariantMap",
        "options",
        "Delete",
        "RemoveDevice",
        "RequestSyncAction",
        "sync_action",
        "SetBitmapLocation",
        "value",
        "Start",
        "Stop",
        "ActiveDevices",
        "QList<UDisks2::ActiveDeviceInfo>",
        "BitmapLocation",
        "ChildConfiguration",
        "QList<std::pair<QString,QVariantMap>>",
        "ChunkSize",
        "Degraded",
        "Level",
        "Name",
        "NumDevices",
        "Running",
        "Size",
        "SyncAction",
        "SyncCompleted",
        "SyncRate",
        "SyncRemainingTime",
        "UUID"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'AddDevice'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QDBusObjectPath &, const QVariantMap &)>(1, 3, QMC::AccessPublic, 0x80000000 | 2, {{
            { 0x80000000 | 4, 5 }, { 0x80000000 | 6, 7 },
        }}),
        // Slot 'Delete'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QVariantMap &)>(8, 3, QMC::AccessPublic, 0x80000000 | 2, {{
            { 0x80000000 | 6, 7 },
        }}),
        // Slot 'RemoveDevice'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QDBusObjectPath &, const QVariantMap &)>(9, 3, QMC::AccessPublic, 0x80000000 | 2, {{
            { 0x80000000 | 4, 5 }, { 0x80000000 | 6, 7 },
        }}),
        // Slot 'RequestSyncAction'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QString &, const QVariantMap &)>(10, 3, QMC::AccessPublic, 0x80000000 | 2, {{
            { QMetaType::QString, 11 }, { 0x80000000 | 6, 7 },
        }}),
        // Slot 'SetBitmapLocation'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QByteArray &, const QVariantMap &)>(12, 3, QMC::AccessPublic, 0x80000000 | 2, {{
            { QMetaType::QByteArray, 13 }, { 0x80000000 | 6, 7 },
        }}),
        // Slot 'Start'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QVariantMap &)>(14, 3, QMC::AccessPublic, 0x80000000 | 2, {{
            { 0x80000000 | 6, 7 },
        }}),
        // Slot 'Stop'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QVariantMap &)>(15, 3, QMC::AccessPublic, 0x80000000 | 2, {{
            { 0x80000000 | 6, 7 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'ActiveDevices'
        QtMocHelpers::PropertyData<QList<UDisks2::ActiveDeviceInfo>>(16, 0x80000000 | 17, QMC::DefaultPropertyFlags | QMC::EnumOrFlag),
        // property 'BitmapLocation'
        QtMocHelpers::PropertyData<QByteArray>(18, QMetaType::QByteArray, QMC::DefaultPropertyFlags),
        // property 'ChildConfiguration'
        QtMocHelpers::PropertyData<QList<std::pair<QString,QVariantMap>>>(19, 0x80000000 | 20, QMC::DefaultPropertyFlags | QMC::EnumOrFlag),
        // property 'ChunkSize'
        QtMocHelpers::PropertyData<qulonglong>(21, QMetaType::ULongLong, QMC::DefaultPropertyFlags),
        // property 'Degraded'
        QtMocHelpers::PropertyData<uint>(22, QMetaType::UInt, QMC::DefaultPropertyFlags),
        // property 'Level'
        QtMocHelpers::PropertyData<QString>(23, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'Name'
        QtMocHelpers::PropertyData<QString>(24, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'NumDevices'
        QtMocHelpers::PropertyData<uint>(25, QMetaType::UInt, QMC::DefaultPropertyFlags),
        // property 'Running'
        QtMocHelpers::PropertyData<bool>(26, QMetaType::Bool, QMC::DefaultPropertyFlags),
        // property 'Size'
        QtMocHelpers::PropertyData<qulonglong>(27, QMetaType::ULongLong, QMC::DefaultPropertyFlags),
        // property 'SyncAction'
        QtMocHelpers::PropertyData<QString>(28, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'SyncCompleted'
        QtMocHelpers::PropertyData<double>(29, QMetaType::Double, QMC::DefaultPropertyFlags),
        // property 'SyncRate'
        QtMocHelpers::PropertyData<qulonglong>(30, QMetaType::ULongLong, QMC::DefaultPropertyFlags),
        // property 'SyncRemainingTime'
        QtMocHelpers::PropertyData<qulonglong>(31, QMetaType::ULongLong, QMC::DefaultPropertyFlags),
        // property 'UUID'
        QtMocHelpers::PropertyData<QString>(32, QMetaType::QString, QMC::DefaultPropertyFlags),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<OrgFreedesktopUDisks2MDRaidInterface, qt_meta_tag_ZN36OrgFreedesktopUDisks2MDRaidInterfaceE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject OrgFreedesktopUDisks2MDRaidInterface::staticMetaObject = { {
    QMetaObject::SuperData::link<QDBusAbstractInterface::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN36OrgFreedesktopUDisks2MDRaidInterfaceE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN36OrgFreedesktopUDisks2MDRaidInterfaceE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN36OrgFreedesktopUDisks2MDRaidInterfaceE_t>.metaTypes,
    nullptr
} };

void OrgFreedesktopUDisks2MDRaidInterface::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<OrgFreedesktopUDisks2MDRaidInterface *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: { QDBusPendingReply<> _r = _t->AddDevice((*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 1: { QDBusPendingReply<> _r = _t->Delete((*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 2: { QDBusPendingReply<> _r = _t->RemoveDevice((*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 3: { QDBusPendingReply<> _r = _t->RequestSyncAction((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 4: { QDBusPendingReply<> _r = _t->SetBitmapLocation((*reinterpret_cast<std::add_pointer_t<QByteArray>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 5: { QDBusPendingReply<> _r = _t->Start((*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 6: { QDBusPendingReply<> _r = _t->Stop((*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 0:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QList<UDisks2::ActiveDeviceInfo> >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QList<UDisks2::ActiveDeviceInfo>*>(_v) = _t->activeDevices(); break;
        case 1: *reinterpret_cast<QByteArray*>(_v) = _t->bitmapLocation(); break;
        case 2: *reinterpret_cast<QList<std::pair<QString,QVariantMap>>*>(_v) = _t->childConfiguration(); break;
        case 3: *reinterpret_cast<qulonglong*>(_v) = _t->chunkSize(); break;
        case 4: *reinterpret_cast<uint*>(_v) = _t->degraded(); break;
        case 5: *reinterpret_cast<QString*>(_v) = _t->level(); break;
        case 6: *reinterpret_cast<QString*>(_v) = _t->name(); break;
        case 7: *reinterpret_cast<uint*>(_v) = _t->numDevices(); break;
        case 8: *reinterpret_cast<bool*>(_v) = _t->running(); break;
        case 9: *reinterpret_cast<qulonglong*>(_v) = _t->size(); break;
        case 10: *reinterpret_cast<QString*>(_v) = _t->syncAction(); break;
        case 11: *reinterpret_cast<double*>(_v) = _t->syncCompleted(); break;
        case 12: *reinterpret_cast<qulonglong*>(_v) = _t->syncRate(); break;
        case 13: *reinterpret_cast<qulonglong*>(_v) = _t->syncRemainingTime(); break;
        case 14: *reinterpret_cast<QString*>(_v) = _t->uUID(); break;
        default: break;
        }
    }
}

const QMetaObject *OrgFreedesktopUDisks2MDRaidInterface::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *OrgFreedesktopUDisks2MDRaidInterface::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN36OrgFreedesktopUDisks2MDRaidInterfaceE_t>.strings))
        return static_cast<void*>(this);
    return QDBusAbstractInterface::qt_metacast(_clname);
}

int OrgFreedesktopUDisks2MDRaidInterface::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDBusAbstractInterface::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 7)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 7)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 7;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 15;
    }
    return _id;
}
namespace {
struct qt_meta_tag_ZN37OrgFreedesktopUDisks2ManagerInterfaceE_t {};
} // unnamed namespace

template <> constexpr inline auto OrgFreedesktopUDisks2ManagerInterface::qt_create_metaobjectdata<qt_meta_tag_ZN37OrgFreedesktopUDisks2ManagerInterfaceE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "OrgFreedesktopUDisks2ManagerInterface",
        "CanCheck",
        "QDBusPendingReply<std::pair<bool,QString>>",
        "",
        "type",
        "CanFormat",
        "CanRepair",
        "CanResize",
        "QDBusPendingReply<std::pair<bool,std::pair<quint64,QString>>>",
        "EnableModules",
        "QDBusPendingReply<>",
        "enable",
        "GetBlockDevices",
        "QDBusPendingReply<QList<QDBusObjectPath>>",
        "QVariantMap",
        "options",
        "LoopSetup",
        "QDBusPendingReply<QDBusObjectPath>",
        "QDBusUnixFileDescriptor",
        "fd",
        "MDRaidCreate",
        "QList<QDBusObjectPath>",
        "blocks",
        "level",
        "name",
        "chunk",
        "ResolveDevice",
        "devspec",
        "DefaultEncryptionType",
        "SupportedEncryptionTypes",
        "SupportedFilesystems",
        "Version"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'CanCheck'
        QtMocHelpers::SlotData<QDBusPendingReply<QPair<bool,QString> >(const QString &)>(1, 3, QMC::AccessPublic, 0x80000000 | 2, {{
            { QMetaType::QString, 4 },
        }}),
        // Slot 'CanFormat'
        QtMocHelpers::SlotData<QDBusPendingReply<QPair<bool,QString> >(const QString &)>(5, 3, QMC::AccessPublic, 0x80000000 | 2, {{
            { QMetaType::QString, 4 },
        }}),
        // Slot 'CanRepair'
        QtMocHelpers::SlotData<QDBusPendingReply<QPair<bool,QString> >(const QString &)>(6, 3, QMC::AccessPublic, 0x80000000 | 2, {{
            { QMetaType::QString, 4 },
        }}),
        // Slot 'CanResize'
        QtMocHelpers::SlotData<QDBusPendingReply<QPair<bool,QPair<quint64,QString>> >(const QString &)>(7, 3, QMC::AccessPublic, 0x80000000 | 8, {{
            { QMetaType::QString, 4 },
        }}),
        // Slot 'EnableModules'
        QtMocHelpers::SlotData<QDBusPendingReply<>(bool)>(9, 3, QMC::AccessPublic, 0x80000000 | 10, {{
            { QMetaType::Bool, 11 },
        }}),
        // Slot 'GetBlockDevices'
        QtMocHelpers::SlotData<QDBusPendingReply<QList<QDBusObjectPath> >(const QVariantMap &)>(12, 3, QMC::AccessPublic, 0x80000000 | 13, {{
            { 0x80000000 | 14, 15 },
        }}),
        // Slot 'LoopSetup'
        QtMocHelpers::SlotData<QDBusPendingReply<QDBusObjectPath>(const QDBusUnixFileDescriptor &, const QVariantMap &)>(16, 3, QMC::AccessPublic, 0x80000000 | 17, {{
            { 0x80000000 | 18, 19 }, { 0x80000000 | 14, 15 },
        }}),
        // Slot 'MDRaidCreate'
        QtMocHelpers::SlotData<QDBusPendingReply<QDBusObjectPath>(const QList<QDBusObjectPath> &, const QString &, const QString &, qulonglong, const QVariantMap &)>(20, 3, QMC::AccessPublic, 0x80000000 | 17, {{
            { 0x80000000 | 21, 22 }, { QMetaType::QString, 23 }, { QMetaType::QString, 24 }, { QMetaType::ULongLong, 25 },
            { 0x80000000 | 14, 15 },
        }}),
        // Slot 'ResolveDevice'
        QtMocHelpers::SlotData<QDBusPendingReply<QList<QDBusObjectPath> >(const QVariantMap &, const QVariantMap &)>(26, 3, QMC::AccessPublic, 0x80000000 | 13, {{
            { 0x80000000 | 14, 27 }, { 0x80000000 | 14, 15 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'DefaultEncryptionType'
        QtMocHelpers::PropertyData<QString>(28, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'SupportedEncryptionTypes'
        QtMocHelpers::PropertyData<QStringList>(29, QMetaType::QStringList, QMC::DefaultPropertyFlags),
        // property 'SupportedFilesystems'
        QtMocHelpers::PropertyData<QStringList>(30, QMetaType::QStringList, QMC::DefaultPropertyFlags),
        // property 'Version'
        QtMocHelpers::PropertyData<QString>(31, QMetaType::QString, QMC::DefaultPropertyFlags),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<OrgFreedesktopUDisks2ManagerInterface, qt_meta_tag_ZN37OrgFreedesktopUDisks2ManagerInterfaceE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject OrgFreedesktopUDisks2ManagerInterface::staticMetaObject = { {
    QMetaObject::SuperData::link<QDBusAbstractInterface::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN37OrgFreedesktopUDisks2ManagerInterfaceE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN37OrgFreedesktopUDisks2ManagerInterfaceE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN37OrgFreedesktopUDisks2ManagerInterfaceE_t>.metaTypes,
    nullptr
} };

void OrgFreedesktopUDisks2ManagerInterface::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<OrgFreedesktopUDisks2ManagerInterface *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: { QDBusPendingReply<std::pair<bool,QString>> _r = _t->CanCheck((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<std::pair<bool,QString>>*>(_a[0]) = std::move(_r); }  break;
        case 1: { QDBusPendingReply<std::pair<bool,QString>> _r = _t->CanFormat((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<std::pair<bool,QString>>*>(_a[0]) = std::move(_r); }  break;
        case 2: { QDBusPendingReply<std::pair<bool,QString>> _r = _t->CanRepair((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<std::pair<bool,QString>>*>(_a[0]) = std::move(_r); }  break;
        case 3: { QDBusPendingReply<std::pair<bool,std::pair<quint64,QString>>> _r = _t->CanResize((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<std::pair<bool,std::pair<quint64,QString>>>*>(_a[0]) = std::move(_r); }  break;
        case 4: { QDBusPendingReply<> _r = _t->EnableModules((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 5: { QDBusPendingReply<QList<QDBusObjectPath>> _r = _t->GetBlockDevices((*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QList<QDBusObjectPath>>*>(_a[0]) = std::move(_r); }  break;
        case 6: { QDBusPendingReply<QDBusObjectPath> _r = _t->LoopSetup((*reinterpret_cast<std::add_pointer_t<QDBusUnixFileDescriptor>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QDBusObjectPath>*>(_a[0]) = std::move(_r); }  break;
        case 7: { QDBusPendingReply<QDBusObjectPath> _r = _t->MDRaidCreate((*reinterpret_cast<std::add_pointer_t<QList<QDBusObjectPath>>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<qulonglong>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[5])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QDBusObjectPath>*>(_a[0]) = std::move(_r); }  break;
        case 8: { QDBusPendingReply<QList<QDBusObjectPath>> _r = _t->ResolveDevice((*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QList<QDBusObjectPath>>*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->defaultEncryptionType(); break;
        case 1: *reinterpret_cast<QStringList*>(_v) = _t->supportedEncryptionTypes(); break;
        case 2: *reinterpret_cast<QStringList*>(_v) = _t->supportedFilesystems(); break;
        case 3: *reinterpret_cast<QString*>(_v) = _t->version(); break;
        default: break;
        }
    }
}

const QMetaObject *OrgFreedesktopUDisks2ManagerInterface::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *OrgFreedesktopUDisks2ManagerInterface::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN37OrgFreedesktopUDisks2ManagerInterfaceE_t>.strings))
        return static_cast<void*>(this);
    return QDBusAbstractInterface::qt_metacast(_clname);
}

int OrgFreedesktopUDisks2ManagerInterface::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDBusAbstractInterface::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 9)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 9)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 9;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    }
    return _id;
}
namespace {
struct qt_meta_tag_ZN39OrgFreedesktopUDisks2PartitionInterfaceE_t {};
} // unnamed namespace

template <> constexpr inline auto OrgFreedesktopUDisks2PartitionInterface::qt_create_metaobjectdata<qt_meta_tag_ZN39OrgFreedesktopUDisks2PartitionInterfaceE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "OrgFreedesktopUDisks2PartitionInterface",
        "Delete",
        "QDBusPendingReply<>",
        "",
        "QVariantMap",
        "options",
        "Resize",
        "size",
        "SetFlags",
        "flags",
        "SetName",
        "name",
        "SetType",
        "type",
        "Flags",
        "IsContained",
        "IsContainer",
        "Name",
        "Number",
        "Offset",
        "Size",
        "Table",
        "QDBusObjectPath",
        "Type",
        "UUID"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'Delete'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QVariantMap &)>(1, 3, QMC::AccessPublic, 0x80000000 | 2, {{
            { 0x80000000 | 4, 5 },
        }}),
        // Slot 'Resize'
        QtMocHelpers::SlotData<QDBusPendingReply<>(qulonglong, const QVariantMap &)>(6, 3, QMC::AccessPublic, 0x80000000 | 2, {{
            { QMetaType::ULongLong, 7 }, { 0x80000000 | 4, 5 },
        }}),
        // Slot 'SetFlags'
        QtMocHelpers::SlotData<QDBusPendingReply<>(qulonglong, const QVariantMap &)>(8, 3, QMC::AccessPublic, 0x80000000 | 2, {{
            { QMetaType::ULongLong, 9 }, { 0x80000000 | 4, 5 },
        }}),
        // Slot 'SetName'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QString &, const QVariantMap &)>(10, 3, QMC::AccessPublic, 0x80000000 | 2, {{
            { QMetaType::QString, 11 }, { 0x80000000 | 4, 5 },
        }}),
        // Slot 'SetType'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QString &, const QVariantMap &)>(12, 3, QMC::AccessPublic, 0x80000000 | 2, {{
            { QMetaType::QString, 13 }, { 0x80000000 | 4, 5 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'Flags'
        QtMocHelpers::PropertyData<qulonglong>(14, QMetaType::ULongLong, QMC::DefaultPropertyFlags),
        // property 'IsContained'
        QtMocHelpers::PropertyData<bool>(15, QMetaType::Bool, QMC::DefaultPropertyFlags),
        // property 'IsContainer'
        QtMocHelpers::PropertyData<bool>(16, QMetaType::Bool, QMC::DefaultPropertyFlags),
        // property 'Name'
        QtMocHelpers::PropertyData<QString>(17, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'Number'
        QtMocHelpers::PropertyData<uint>(18, QMetaType::UInt, QMC::DefaultPropertyFlags),
        // property 'Offset'
        QtMocHelpers::PropertyData<qulonglong>(19, QMetaType::ULongLong, QMC::DefaultPropertyFlags),
        // property 'Size'
        QtMocHelpers::PropertyData<qulonglong>(20, QMetaType::ULongLong, QMC::DefaultPropertyFlags),
        // property 'Table'
        QtMocHelpers::PropertyData<QDBusObjectPath>(21, 0x80000000 | 22, QMC::DefaultPropertyFlags | QMC::EnumOrFlag),
        // property 'Type'
        QtMocHelpers::PropertyData<QString>(23, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'UUID'
        QtMocHelpers::PropertyData<QString>(24, QMetaType::QString, QMC::DefaultPropertyFlags),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<OrgFreedesktopUDisks2PartitionInterface, qt_meta_tag_ZN39OrgFreedesktopUDisks2PartitionInterfaceE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject OrgFreedesktopUDisks2PartitionInterface::staticMetaObject = { {
    QMetaObject::SuperData::link<QDBusAbstractInterface::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN39OrgFreedesktopUDisks2PartitionInterfaceE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN39OrgFreedesktopUDisks2PartitionInterfaceE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN39OrgFreedesktopUDisks2PartitionInterfaceE_t>.metaTypes,
    nullptr
} };

void OrgFreedesktopUDisks2PartitionInterface::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<OrgFreedesktopUDisks2PartitionInterface *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: { QDBusPendingReply<> _r = _t->Delete((*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 1: { QDBusPendingReply<> _r = _t->Resize((*reinterpret_cast<std::add_pointer_t<qulonglong>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 2: { QDBusPendingReply<> _r = _t->SetFlags((*reinterpret_cast<std::add_pointer_t<qulonglong>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 3: { QDBusPendingReply<> _r = _t->SetName((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 4: { QDBusPendingReply<> _r = _t->SetType((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<qulonglong*>(_v) = _t->flags(); break;
        case 1: *reinterpret_cast<bool*>(_v) = _t->isContained(); break;
        case 2: *reinterpret_cast<bool*>(_v) = _t->isContainer(); break;
        case 3: *reinterpret_cast<QString*>(_v) = _t->name(); break;
        case 4: *reinterpret_cast<uint*>(_v) = _t->number(); break;
        case 5: *reinterpret_cast<qulonglong*>(_v) = _t->offset(); break;
        case 6: *reinterpret_cast<qulonglong*>(_v) = _t->size(); break;
        case 7: *reinterpret_cast<QDBusObjectPath*>(_v) = _t->table(); break;
        case 8: *reinterpret_cast<QString*>(_v) = _t->type(); break;
        case 9: *reinterpret_cast<QString*>(_v) = _t->uUID(); break;
        default: break;
        }
    }
}

const QMetaObject *OrgFreedesktopUDisks2PartitionInterface::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *OrgFreedesktopUDisks2PartitionInterface::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN39OrgFreedesktopUDisks2PartitionInterfaceE_t>.strings))
        return static_cast<void*>(this);
    return QDBusAbstractInterface::qt_metacast(_clname);
}

int OrgFreedesktopUDisks2PartitionInterface::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDBusAbstractInterface::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 5)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 5)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 5;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 10;
    }
    return _id;
}
namespace {
struct qt_meta_tag_ZN44OrgFreedesktopUDisks2PartitionTableInterfaceE_t {};
} // unnamed namespace

template <> constexpr inline auto OrgFreedesktopUDisks2PartitionTableInterface::qt_create_metaobjectdata<qt_meta_tag_ZN44OrgFreedesktopUDisks2PartitionTableInterfaceE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "OrgFreedesktopUDisks2PartitionTableInterface",
        "CreatePartition",
        "QDBusPendingReply<QDBusObjectPath>",
        "",
        "offset",
        "size",
        "type",
        "name",
        "QVariantMap",
        "options",
        "CreatePartitionAndFormat",
        "format_type",
        "format_options",
        "Partitions",
        "QList<QDBusObjectPath>",
        "Type"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'CreatePartition'
        QtMocHelpers::SlotData<QDBusPendingReply<QDBusObjectPath>(qulonglong, qulonglong, const QString &, const QString &, const QVariantMap &)>(1, 3, QMC::AccessPublic, 0x80000000 | 2, {{
            { QMetaType::ULongLong, 4 }, { QMetaType::ULongLong, 5 }, { QMetaType::QString, 6 }, { QMetaType::QString, 7 },
            { 0x80000000 | 8, 9 },
        }}),
        // Slot 'CreatePartitionAndFormat'
        QtMocHelpers::SlotData<QDBusPendingReply<QDBusObjectPath>(qulonglong, qulonglong, const QString &, const QString &, const QVariantMap &, const QString &, const QVariantMap &)>(10, 3, QMC::AccessPublic, 0x80000000 | 2, {{
            { QMetaType::ULongLong, 4 }, { QMetaType::ULongLong, 5 }, { QMetaType::QString, 6 }, { QMetaType::QString, 7 },
            { 0x80000000 | 8, 9 }, { QMetaType::QString, 11 }, { 0x80000000 | 8, 12 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'Partitions'
        QtMocHelpers::PropertyData<QList<QDBusObjectPath>>(13, 0x80000000 | 14, QMC::DefaultPropertyFlags | QMC::EnumOrFlag),
        // property 'Type'
        QtMocHelpers::PropertyData<QString>(15, QMetaType::QString, QMC::DefaultPropertyFlags),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<OrgFreedesktopUDisks2PartitionTableInterface, qt_meta_tag_ZN44OrgFreedesktopUDisks2PartitionTableInterfaceE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject OrgFreedesktopUDisks2PartitionTableInterface::staticMetaObject = { {
    QMetaObject::SuperData::link<QDBusAbstractInterface::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN44OrgFreedesktopUDisks2PartitionTableInterfaceE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN44OrgFreedesktopUDisks2PartitionTableInterfaceE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN44OrgFreedesktopUDisks2PartitionTableInterfaceE_t>.metaTypes,
    nullptr
} };

void OrgFreedesktopUDisks2PartitionTableInterface::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<OrgFreedesktopUDisks2PartitionTableInterface *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: { QDBusPendingReply<QDBusObjectPath> _r = _t->CreatePartition((*reinterpret_cast<std::add_pointer_t<qulonglong>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<qulonglong>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[5])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QDBusObjectPath>*>(_a[0]) = std::move(_r); }  break;
        case 1: { QDBusPendingReply<QDBusObjectPath> _r = _t->CreatePartitionAndFormat((*reinterpret_cast<std::add_pointer_t<qulonglong>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<qulonglong>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[6])),(*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[7])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QDBusObjectPath>*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QList<QDBusObjectPath>*>(_v) = _t->partitions(); break;
        case 1: *reinterpret_cast<QString*>(_v) = _t->type(); break;
        default: break;
        }
    }
}

const QMetaObject *OrgFreedesktopUDisks2PartitionTableInterface::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *OrgFreedesktopUDisks2PartitionTableInterface::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN44OrgFreedesktopUDisks2PartitionTableInterfaceE_t>.strings))
        return static_cast<void*>(this);
    return QDBusAbstractInterface::qt_metacast(_clname);
}

int OrgFreedesktopUDisks2PartitionTableInterface::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDBusAbstractInterface::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 2)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 2)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 2;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    }
    return _id;
}
namespace {
struct qt_meta_tag_ZN39OrgFreedesktopUDisks2SwapspaceInterfaceE_t {};
} // unnamed namespace

template <> constexpr inline auto OrgFreedesktopUDisks2SwapspaceInterface::qt_create_metaobjectdata<qt_meta_tag_ZN39OrgFreedesktopUDisks2SwapspaceInterfaceE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "OrgFreedesktopUDisks2SwapspaceInterface",
        "SetLabel",
        "QDBusPendingReply<>",
        "",
        "label",
        "QVariantMap",
        "options",
        "Start",
        "Stop",
        "Active"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'SetLabel'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QString &, const QVariantMap &)>(1, 3, QMC::AccessPublic, 0x80000000 | 2, {{
            { QMetaType::QString, 4 }, { 0x80000000 | 5, 6 },
        }}),
        // Slot 'Start'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QVariantMap &)>(7, 3, QMC::AccessPublic, 0x80000000 | 2, {{
            { 0x80000000 | 5, 6 },
        }}),
        // Slot 'Stop'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QVariantMap &)>(8, 3, QMC::AccessPublic, 0x80000000 | 2, {{
            { 0x80000000 | 5, 6 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'Active'
        QtMocHelpers::PropertyData<bool>(9, QMetaType::Bool, QMC::DefaultPropertyFlags),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<OrgFreedesktopUDisks2SwapspaceInterface, qt_meta_tag_ZN39OrgFreedesktopUDisks2SwapspaceInterfaceE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject OrgFreedesktopUDisks2SwapspaceInterface::staticMetaObject = { {
    QMetaObject::SuperData::link<QDBusAbstractInterface::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN39OrgFreedesktopUDisks2SwapspaceInterfaceE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN39OrgFreedesktopUDisks2SwapspaceInterfaceE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN39OrgFreedesktopUDisks2SwapspaceInterfaceE_t>.metaTypes,
    nullptr
} };

void OrgFreedesktopUDisks2SwapspaceInterface::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<OrgFreedesktopUDisks2SwapspaceInterface *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: { QDBusPendingReply<> _r = _t->SetLabel((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 1: { QDBusPendingReply<> _r = _t->Start((*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 2: { QDBusPendingReply<> _r = _t->Stop((*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<bool*>(_v) = _t->active(); break;
        default: break;
        }
    }
}

const QMetaObject *OrgFreedesktopUDisks2SwapspaceInterface::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *OrgFreedesktopUDisks2SwapspaceInterface::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN39OrgFreedesktopUDisks2SwapspaceInterfaceE_t>.strings))
        return static_cast<void*>(this);
    return QDBusAbstractInterface::qt_metacast(_clname);
}

int OrgFreedesktopUDisks2SwapspaceInterface::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDBusAbstractInterface::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 3)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 3)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 3;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    return _id;
}
QT_WARNING_POP
