/****************************************************************************
** Meta object code from reading C++ file 'dudisksjob.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../udisks2-qt6/dudisksjob.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'dudisksjob.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN10DUDisksJobE_t {};
} // unnamed namespace

template <> constexpr inline auto DUDisksJob::qt_create_metaobjectdata<qt_meta_tag_ZN10DUDisksJobE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "DUDisksJob",
        "completed",
        "",
        "success",
        "message",
        "progressChanged",
        "progress",
        "rateChanged",
        "rate",
        "expectedEndTimeChanged",
        "expectedEndTime",
        "cancel",
        "QVariantMap",
        "options",
        "onPropertiesChanged",
        "interface",
        "changed_properties",
        "path",
        "objects",
        "cancelable",
        "progressValid",
        "operation",
        "startedByUid",
        "bytes",
        "startTime"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'completed'
        QtMocHelpers::SignalData<void(bool, QString)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 3 }, { QMetaType::QString, 4 },
        }}),
        // Signal 'progressChanged'
        QtMocHelpers::SignalData<void(double)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 6 },
        }}),
        // Signal 'rateChanged'
        QtMocHelpers::SignalData<void(quint64)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::ULongLong, 8 },
        }}),
        // Signal 'expectedEndTimeChanged'
        QtMocHelpers::SignalData<void(quint64)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::ULongLong, 10 },
        }}),
        // Slot 'cancel'
        QtMocHelpers::SlotData<void(const QVariantMap &)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 12, 13 },
        }}),
        // Slot 'onPropertiesChanged'
        QtMocHelpers::SlotData<void(const QString &, const QVariantMap &)>(14, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 15 }, { 0x80000000 | 12, 16 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'path'
        QtMocHelpers::PropertyData<QString>(17, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant | QMC::Final),
        // property 'objects'
        QtMocHelpers::PropertyData<QStringList>(18, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Constant | QMC::Final),
        // property 'cancelable'
        QtMocHelpers::PropertyData<bool>(19, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant | QMC::Final),
        // property 'progressValid'
        QtMocHelpers::PropertyData<bool>(20, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant | QMC::Final),
        // property 'progress'
        QtMocHelpers::PropertyData<double>(6, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Final, 1),
        // property 'operation'
        QtMocHelpers::PropertyData<QString>(21, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant | QMC::Final),
        // property 'startedByUid'
        QtMocHelpers::PropertyData<quint32>(22, QMetaType::UInt, QMC::DefaultPropertyFlags | QMC::Constant | QMC::Final),
        // property 'bytes'
        QtMocHelpers::PropertyData<quint64>(23, QMetaType::ULongLong, QMC::DefaultPropertyFlags | QMC::Constant | QMC::Final),
        // property 'expectedEndTime'
        QtMocHelpers::PropertyData<quint64>(10, QMetaType::ULongLong, QMC::DefaultPropertyFlags | QMC::Final, 3),
        // property 'rate'
        QtMocHelpers::PropertyData<quint64>(8, QMetaType::ULongLong, QMC::DefaultPropertyFlags | QMC::Final, 2),
        // property 'startTime'
        QtMocHelpers::PropertyData<quint64>(24, QMetaType::ULongLong, QMC::DefaultPropertyFlags | QMC::Constant | QMC::Final),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<DUDisksJob, qt_meta_tag_ZN10DUDisksJobE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject DUDisksJob::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10DUDisksJobE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10DUDisksJobE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN10DUDisksJobE_t>.metaTypes,
    nullptr
} };

void DUDisksJob::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<DUDisksJob *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->completed((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 1: _t->progressChanged((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 2: _t->rateChanged((*reinterpret_cast<std::add_pointer_t<quint64>>(_a[1]))); break;
        case 3: _t->expectedEndTimeChanged((*reinterpret_cast<std::add_pointer_t<quint64>>(_a[1]))); break;
        case 4: _t->cancel((*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[1]))); break;
        case 5: _t->onPropertiesChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[2]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (DUDisksJob::*)(bool , QString )>(_a, &DUDisksJob::completed, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (DUDisksJob::*)(double )>(_a, &DUDisksJob::progressChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (DUDisksJob::*)(quint64 )>(_a, &DUDisksJob::rateChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (DUDisksJob::*)(quint64 )>(_a, &DUDisksJob::expectedEndTimeChanged, 3))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->path(); break;
        case 1: *reinterpret_cast<QStringList*>(_v) = _t->objects(); break;
        case 2: *reinterpret_cast<bool*>(_v) = _t->cancelable(); break;
        case 3: *reinterpret_cast<bool*>(_v) = _t->progressValid(); break;
        case 4: *reinterpret_cast<double*>(_v) = _t->progress(); break;
        case 5: *reinterpret_cast<QString*>(_v) = _t->operation(); break;
        case 6: *reinterpret_cast<quint32*>(_v) = _t->startedByUid(); break;
        case 7: *reinterpret_cast<quint64*>(_v) = _t->bytes(); break;
        case 8: *reinterpret_cast<quint64*>(_v) = _t->expectedEndTime(); break;
        case 9: *reinterpret_cast<quint64*>(_v) = _t->rate(); break;
        case 10: *reinterpret_cast<quint64*>(_v) = _t->startTime(); break;
        default: break;
        }
    }
}

const QMetaObject *DUDisksJob::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *DUDisksJob::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10DUDisksJobE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int DUDisksJob::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 6)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 6)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 6;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 11;
    }
    return _id;
}

// SIGNAL 0
void DUDisksJob::completed(bool _t1, QString _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2);
}

// SIGNAL 1
void DUDisksJob::progressChanged(double _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void DUDisksJob::rateChanged(quint64 _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void DUDisksJob::expectedEndTimeChanged(quint64 _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}
QT_WARNING_POP
