/****************************************************************************
** Meta object code from reading C++ file 'ddiskdevice.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../udisks2-qt6/ddiskdevice.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'ddiskdevice.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN11DDiskDeviceE_t {};
} // unnamed namespace

template <> constexpr inline auto DDiskDevice::qt_create_metaobjectdata<qt_meta_tag_ZN11DDiskDeviceE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "DDiskDevice",
        "eject",
        "",
        "QVariantMap",
        "options",
        "powerOff",
        "setConfiguration",
        "value",
        "path",
        "canPowerOff",
        "configuration",
        "connectionBus",
        "ejectable",
        "id",
        "media",
        "mediaAvailable",
        "mediaChangeDetected",
        "mediaCompatibility",
        "mediaRemovable",
        "model",
        "optical",
        "opticalBlank",
        "opticalNumAudioTracks",
        "opticalNumDataTracks",
        "opticalNumSessions",
        "opticalNumTracks",
        "removable",
        "revision",
        "rotationRate",
        "seat",
        "serial",
        "siblingId",
        "size",
        "sortKey",
        "timeDetected",
        "timeMediaDetected",
        "vendor",
        "WWN"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'eject'
        QtMocHelpers::SlotData<void(const QVariantMap &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Slot 'powerOff'
        QtMocHelpers::SlotData<void(const QVariantMap &)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Slot 'setConfiguration'
        QtMocHelpers::SlotData<void(const QVariantMap &, const QVariantMap &)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 7 }, { 0x80000000 | 3, 4 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'path'
        QtMocHelpers::PropertyData<QString>(8, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant | QMC::Final),
        // property 'canPowerOff'
        QtMocHelpers::PropertyData<bool>(9, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant | QMC::Final),
        // property 'configuration'
        QtMocHelpers::PropertyData<QVariantMap>(10, 0x80000000 | 3, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant | QMC::Final),
        // property 'connectionBus'
        QtMocHelpers::PropertyData<QString>(11, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant | QMC::Final),
        // property 'ejectable'
        QtMocHelpers::PropertyData<bool>(12, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant | QMC::Final),
        // property 'id'
        QtMocHelpers::PropertyData<QString>(13, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant | QMC::Final),
        // property 'media'
        QtMocHelpers::PropertyData<QString>(14, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant | QMC::Final),
        // property 'mediaAvailable'
        QtMocHelpers::PropertyData<bool>(15, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant | QMC::Final),
        // property 'mediaChangeDetected'
        QtMocHelpers::PropertyData<bool>(16, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant | QMC::Final),
        // property 'mediaCompatibility'
        QtMocHelpers::PropertyData<QStringList>(17, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Constant | QMC::Final),
        // property 'mediaRemovable'
        QtMocHelpers::PropertyData<bool>(18, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant | QMC::Final),
        // property 'model'
        QtMocHelpers::PropertyData<QString>(19, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant | QMC::Final),
        // property 'optical'
        QtMocHelpers::PropertyData<bool>(20, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant | QMC::Final),
        // property 'opticalBlank'
        QtMocHelpers::PropertyData<bool>(21, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant | QMC::Final),
        // property 'opticalNumAudioTracks'
        QtMocHelpers::PropertyData<uint>(22, QMetaType::UInt, QMC::DefaultPropertyFlags | QMC::Constant | QMC::Final),
        // property 'opticalNumDataTracks'
        QtMocHelpers::PropertyData<uint>(23, QMetaType::UInt, QMC::DefaultPropertyFlags | QMC::Constant | QMC::Final),
        // property 'opticalNumSessions'
        QtMocHelpers::PropertyData<uint>(24, QMetaType::UInt, QMC::DefaultPropertyFlags | QMC::Constant | QMC::Final),
        // property 'opticalNumTracks'
        QtMocHelpers::PropertyData<uint>(25, QMetaType::UInt, QMC::DefaultPropertyFlags | QMC::Constant | QMC::Final),
        // property 'removable'
        QtMocHelpers::PropertyData<bool>(26, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant | QMC::Final),
        // property 'revision'
        QtMocHelpers::PropertyData<QString>(27, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant | QMC::Final),
        // property 'rotationRate'
        QtMocHelpers::PropertyData<int>(28, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant | QMC::Final),
        // property 'seat'
        QtMocHelpers::PropertyData<QString>(29, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant | QMC::Final),
        // property 'serial'
        QtMocHelpers::PropertyData<QString>(30, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant | QMC::Final),
        // property 'siblingId'
        QtMocHelpers::PropertyData<QString>(31, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant | QMC::Final),
        // property 'size'
        QtMocHelpers::PropertyData<qulonglong>(32, QMetaType::ULongLong, QMC::DefaultPropertyFlags | QMC::Constant | QMC::Final),
        // property 'sortKey'
        QtMocHelpers::PropertyData<QString>(33, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant | QMC::Final),
        // property 'timeDetected'
        QtMocHelpers::PropertyData<qulonglong>(34, QMetaType::ULongLong, QMC::DefaultPropertyFlags | QMC::Constant | QMC::Final),
        // property 'timeMediaDetected'
        QtMocHelpers::PropertyData<qulonglong>(35, QMetaType::ULongLong, QMC::DefaultPropertyFlags | QMC::Constant | QMC::Final),
        // property 'vendor'
        QtMocHelpers::PropertyData<QString>(36, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant | QMC::Final),
        // property 'WWN'
        QtMocHelpers::PropertyData<QString>(37, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant | QMC::Final),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<DDiskDevice, qt_meta_tag_ZN11DDiskDeviceE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject DDiskDevice::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11DDiskDeviceE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11DDiskDeviceE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN11DDiskDeviceE_t>.metaTypes,
    nullptr
} };

void DDiskDevice::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<DDiskDevice *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->eject((*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[1]))); break;
        case 1: _t->powerOff((*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[1]))); break;
        case 2: _t->setConfiguration((*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[2]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->path(); break;
        case 1: *reinterpret_cast<bool*>(_v) = _t->canPowerOff(); break;
        case 2: *reinterpret_cast<QVariantMap*>(_v) = _t->configuration(); break;
        case 3: *reinterpret_cast<QString*>(_v) = _t->connectionBus(); break;
        case 4: *reinterpret_cast<bool*>(_v) = _t->ejectable(); break;
        case 5: *reinterpret_cast<QString*>(_v) = _t->id(); break;
        case 6: *reinterpret_cast<QString*>(_v) = _t->media(); break;
        case 7: *reinterpret_cast<bool*>(_v) = _t->mediaAvailable(); break;
        case 8: *reinterpret_cast<bool*>(_v) = _t->mediaChangeDetected(); break;
        case 9: *reinterpret_cast<QStringList*>(_v) = _t->mediaCompatibility(); break;
        case 10: *reinterpret_cast<bool*>(_v) = _t->mediaRemovable(); break;
        case 11: *reinterpret_cast<QString*>(_v) = _t->model(); break;
        case 12: *reinterpret_cast<bool*>(_v) = _t->optical(); break;
        case 13: *reinterpret_cast<bool*>(_v) = _t->opticalBlank(); break;
        case 14: *reinterpret_cast<uint*>(_v) = _t->opticalNumAudioTracks(); break;
        case 15: *reinterpret_cast<uint*>(_v) = _t->opticalNumDataTracks(); break;
        case 16: *reinterpret_cast<uint*>(_v) = _t->opticalNumSessions(); break;
        case 17: *reinterpret_cast<uint*>(_v) = _t->opticalNumTracks(); break;
        case 18: *reinterpret_cast<bool*>(_v) = _t->removable(); break;
        case 19: *reinterpret_cast<QString*>(_v) = _t->revision(); break;
        case 20: *reinterpret_cast<int*>(_v) = _t->rotationRate(); break;
        case 21: *reinterpret_cast<QString*>(_v) = _t->seat(); break;
        case 22: *reinterpret_cast<QString*>(_v) = _t->serial(); break;
        case 23: *reinterpret_cast<QString*>(_v) = _t->siblingId(); break;
        case 24: *reinterpret_cast<qulonglong*>(_v) = _t->size(); break;
        case 25: *reinterpret_cast<QString*>(_v) = _t->sortKey(); break;
        case 26: *reinterpret_cast<qulonglong*>(_v) = _t->timeDetected(); break;
        case 27: *reinterpret_cast<qulonglong*>(_v) = _t->timeMediaDetected(); break;
        case 28: *reinterpret_cast<QString*>(_v) = _t->vendor(); break;
        case 29: *reinterpret_cast<QString*>(_v) = _t->WWN(); break;
        default: break;
        }
    }
}

const QMetaObject *DDiskDevice::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *DDiskDevice::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11DDiskDeviceE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int DDiskDevice::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 3)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 3)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 3;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 30;
    }
    return _id;
}
QT_WARNING_POP
